# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: neurion/sanctum/tx.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'neurion/sanctum/tx.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from amino import amino_pb2 as amino_dot_amino__pb2
from cosmos.msg.v1 import msg_pb2 as cosmos_dot_msg_dot_v1_dot_msg__pb2
from cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2
from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from neurion.sanctum import params_pb2 as neurion_dot_sanctum_dot_params__pb2
from neurion.sanctum import dataset_application_pb2 as neurion_dot_sanctum_dot_dataset__application__pb2
from neurion.sanctum import dataset_usage_request_pb2 as neurion_dot_sanctum_dot_dataset__usage__request__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x18neurion/sanctum/tx.proto\x12\x0fneurion.sanctum\x1a\x11\x61mino/amino.proto\x1a\x17\x63osmos/msg/v1/msg.proto\x1a\x19\x63osmos_proto/cosmos.proto\x1a\x14gogoproto/gogo.proto\x1a\x1cneurion/sanctum/params.proto\x1a)neurion/sanctum/dataset_application.proto\x1a+neurion/sanctum/dataset_usage_request.proto\"\xa8\x01\n\x0fMsgUpdateParams\x12+\n\tauthority\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12\x32\n\x06params\x18\x02 \x01(\x0b\x32\x17.neurion.sanctum.ParamsB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01:4\x82\xe7\xb0*\tauthority\x8a\xe7\xb0*!neurion/x/sanctum/MsgUpdateParams\"\x19\n\x17MsgUpdateParamsResponse\"\xcd\x01\n\x1bMsgSubmitDatasetApplication\x12\x0f\n\x07\x63reator\x18\x01 \x01(\t\x12\x1b\n\x13\x65ncrypted_data_link\x18\x02 \x01(\t\x12\x18\n\x10\x65xplanation_link\x18\x03 \x01(\t\x12\x0f\n\x07\x63ontact\x18\x04 \x01(\t\x12\r\n\x05stake\x18\x05 \x01(\x04\x12\x1d\n\x15proof_of_authenticity\x18\x06 \x01(\t\x12\x19\n\x11\x64\x61taset_usage_fee\x18\x07 \x01(\x04:\x0c\x82\xe7\xb0*\x07\x63reator\"r\n#MsgSubmitDatasetApplicationResponse\x12K\n\x13\x64\x61taset_application\x18\x01 \x01(\x0b\x32#.neurion.sanctum.DatasetApplicationB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\"^\n\x15MsgApproveApplication\x12\x0f\n\x07\x63reator\x18\x01 \x01(\t\x12\x16\n\x0e\x61pplication_id\x18\x02 \x01(\x04\x12\x0e\n\x06reason\x18\x03 \x01(\t:\x0c\x82\xe7\xb0*\x07\x63reator\"\x1f\n\x1dMsgApproveApplicationResponse\"]\n\x14MsgRejectApplication\x12\x0f\n\x07\x63reator\x18\x01 \x01(\t\x12\x16\n\x0e\x61pplication_id\x18\x02 \x01(\x04\x12\x0e\n\x06reason\x18\x03 \x01(\t:\x0c\x82\xe7\xb0*\x07\x63reator\"\x1e\n\x1cMsgRejectApplicationResponse\"[\n\x12MsgDisclaimDataset\x12\x0f\n\x07\x63reator\x18\x01 \x01(\t\x12\x16\n\x0e\x61pplication_id\x18\x02 \x01(\x04\x12\x0e\n\x06reason\x18\x03 \x01(\t:\x0c\x82\xe7\xb0*\x07\x63reator\"\x1c\n\x1aMsgDisclaimDatasetResponse\"\x89\x01\n\x16MsgRequestToUseDataset\x12\x0f\n\x07\x63reator\x18\x01 \x01(\t\x12\x12\n\ndataset_id\x18\x02 \x01(\x04\x12\x0e\n\x06intent\x18\x03 \x01(\t\x12\x1b\n\x13training_repository\x18\x04 \x01(\t\x12\x0f\n\x07\x63ontact\x18\x05 \x01(\t:\x0c\x82\xe7\xb0*\x07\x63reator\"b\n\x1eMsgRequestToUseDatasetResponse\x12@\n\x07request\x18\x01 \x01(\x0b\x32$.neurion.sanctum.DatasetUsageRequestB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\"a\n\x1cMsgCancelDatasetUsageRequest\x12\x0f\n\x07\x63reator\x18\x01 \x01(\t\x12\x12\n\nrequest_id\x18\x02 \x01(\x04\x12\x0e\n\x06reason\x18\x03 \x01(\t:\x0c\x82\xe7\xb0*\x07\x63reator\"&\n$MsgCancelDatasetUsageRequestResponse\"a\n\x1cMsgRejectDatasetUsageRequest\x12\x0f\n\x07\x63reator\x18\x01 \x01(\t\x12\x12\n\nrequest_id\x18\x02 \x01(\x04\x12\x0e\n\x06reason\x18\x03 \x01(\t:\x0c\x82\xe7\xb0*\x07\x63reator\"&\n$MsgRejectDatasetUsageRequestResponse\"b\n\x1dMsgApproveDatasetUsageRequest\x12\x0f\n\x07\x63reator\x18\x01 \x01(\t\x12\x12\n\nrequest_id\x18\x02 \x01(\x04\x12\x0e\n\x06reason\x18\x03 \x01(\t:\x0c\x82\xe7\xb0*\x07\x63reator\"\'\n%MsgApproveDatasetUsageRequestResponse\"C\n\x0fMsgAddProcessor\x12\x0f\n\x07\x63reator\x18\x01 \x01(\t\x12\x11\n\tprocessor\x18\x02 \x01(\t:\x0c\x82\xe7\xb0*\x07\x63reator\"\x19\n\x17MsgAddProcessorResponse\"F\n\x12MsgRemoveProcessor\x12\x0f\n\x07\x63reator\x18\x01 \x01(\t\x12\x11\n\tprocessor\x18\x02 \x01(\t:\x0c\x82\xe7\xb0*\x07\x63reator\"\x1c\n\x1aMsgRemoveProcessorResponse\"R\n\x1dMsgProcessDatasetUsageRequest\x12\x0f\n\x07\x63reator\x18\x01 \x01(\t\x12\x12\n\nrequest_id\x18\x02 \x01(\x04:\x0c\x82\xe7\xb0*\x07\x63reator\"\'\n%MsgProcessDatasetUsageRequestResponse\"c\n\x1cMsgFinishDatasetUsageRequest\x12\x0f\n\x07\x63reator\x18\x01 \x01(\t\x12\x12\n\nrequest_id\x18\x02 \x01(\x04\x12\x10\n\x08\x66\x65\x65\x64\x62\x61\x63k\x18\x03 \x01(\t:\x0c\x82\xe7\xb0*\x07\x63reator\"&\n$MsgFinishDatasetUsageRequestResponse\"q\n\x1dMsgDisputeDatasetUsageRequest\x12\x0f\n\x07\x63reator\x18\x01 \x01(\t\x12\x12\n\nrequest_id\x18\x02 \x01(\x04\x12\r\n\x05model\x18\x03 \x01(\t\x12\x0e\n\x06reason\x18\x04 \x01(\t:\x0c\x82\xe7\xb0*\x07\x63reator\"\'\n%MsgDisputeDatasetUsageRequestResponse\"V\n\x11MsgApproveDispute\x12\x0f\n\x07\x63reator\x18\x01 \x01(\t\x12\x12\n\nrequest_id\x18\x02 \x01(\x04\x12\x0e\n\x06reason\x18\x03 \x01(\t:\x0c\x82\xe7\xb0*\x07\x63reator\"\x1b\n\x19MsgApproveDisputeResponse\"U\n\x10MsgRejectDispute\x12\x0f\n\x07\x63reator\x18\x01 \x01(\t\x12\x12\n\nrequest_id\x18\x02 \x01(\x04\x12\x0e\n\x06reason\x18\x03 \x01(\t:\x0c\x82\xe7\xb0*\x07\x63reator\"\x1a\n\x18MsgRejectDisputeResponse\"B\n\x11MsgStakeToSanctum\x12\x0f\n\x07\x63reator\x18\x01 \x01(\t\x12\x0e\n\x06\x61mount\x18\x02 \x01(\x04:\x0c\x82\xe7\xb0*\x07\x63reator\"\x1b\n\x19MsgStakeToSanctumResponse\"F\n\x15MsgUnstakeFromSanctum\x12\x0f\n\x07\x63reator\x18\x01 \x01(\t\x12\x0e\n\x06\x61mount\x18\x02 \x01(\x04:\x0c\x82\xe7\xb0*\x07\x63reator\"\x1f\n\x1dMsgUnstakeFromSanctumResponse\"/\n\x0eMsgClaimReward\x12\x0f\n\x07\x63reator\x18\x01 \x01(\t:\x0c\x82\xe7\xb0*\x07\x63reator\"\x18\n\x16MsgClaimRewardResponse2\xe3\x10\n\x03Msg\x12Z\n\x0cUpdateParams\x12 .neurion.sanctum.MsgUpdateParams\x1a(.neurion.sanctum.MsgUpdateParamsResponse\x12~\n\x18SubmitDatasetApplication\x12,.neurion.sanctum.MsgSubmitDatasetApplication\x1a\x34.neurion.sanctum.MsgSubmitDatasetApplicationResponse\x12l\n\x12\x41pproveApplication\x12&.neurion.sanctum.MsgApproveApplication\x1a..neurion.sanctum.MsgApproveApplicationResponse\x12i\n\x11RejectApplication\x12%.neurion.sanctum.MsgRejectApplication\x1a-.neurion.sanctum.MsgRejectApplicationResponse\x12\x63\n\x0f\x44isclaimDataset\x12#.neurion.sanctum.MsgDisclaimDataset\x1a+.neurion.sanctum.MsgDisclaimDatasetResponse\x12o\n\x13RequestToUseDataset\x12\'.neurion.sanctum.MsgRequestToUseDataset\x1a/.neurion.sanctum.MsgRequestToUseDatasetResponse\x12\x81\x01\n\x19\x43\x61ncelDatasetUsageRequest\x12-.neurion.sanctum.MsgCancelDatasetUsageRequest\x1a\x35.neurion.sanctum.MsgCancelDatasetUsageRequestResponse\x12\x81\x01\n\x19RejectDatasetUsageRequest\x12-.neurion.sanctum.MsgRejectDatasetUsageRequest\x1a\x35.neurion.sanctum.MsgRejectDatasetUsageRequestResponse\x12\x84\x01\n\x1a\x41pproveDatasetUsageRequest\x12..neurion.sanctum.MsgApproveDatasetUsageRequest\x1a\x36.neurion.sanctum.MsgApproveDatasetUsageRequestResponse\x12Z\n\x0c\x41\x64\x64Processor\x12 .neurion.sanctum.MsgAddProcessor\x1a(.neurion.sanctum.MsgAddProcessorResponse\x12\x63\n\x0fRemoveProcessor\x12#.neurion.sanctum.MsgRemoveProcessor\x1a+.neurion.sanctum.MsgRemoveProcessorResponse\x12\x84\x01\n\x1aProcessDatasetUsageRequest\x12..neurion.sanctum.MsgProcessDatasetUsageRequest\x1a\x36.neurion.sanctum.MsgProcessDatasetUsageRequestResponse\x12\x81\x01\n\x19\x46inishDatasetUsageRequest\x12-.neurion.sanctum.MsgFinishDatasetUsageRequest\x1a\x35.neurion.sanctum.MsgFinishDatasetUsageRequestResponse\x12\x84\x01\n\x1a\x44isputeDatasetUsageRequest\x12..neurion.sanctum.MsgDisputeDatasetUsageRequest\x1a\x36.neurion.sanctum.MsgDisputeDatasetUsageRequestResponse\x12`\n\x0e\x41pproveDispute\x12\".neurion.sanctum.MsgApproveDispute\x1a*.neurion.sanctum.MsgApproveDisputeResponse\x12]\n\rRejectDispute\x12!.neurion.sanctum.MsgRejectDispute\x1a).neurion.sanctum.MsgRejectDisputeResponse\x12`\n\x0eStakeToSanctum\x12\".neurion.sanctum.MsgStakeToSanctum\x1a*.neurion.sanctum.MsgStakeToSanctumResponse\x12l\n\x12UnstakeFromSanctum\x12&.neurion.sanctum.MsgUnstakeFromSanctum\x1a..neurion.sanctum.MsgUnstakeFromSanctumResponse\x12W\n\x0b\x43laimReward\x12\x1f.neurion.sanctum.MsgClaimReward\x1a\'.neurion.sanctum.MsgClaimRewardResponse\x1a\x05\x80\xe7\xb0*\x01\x42\x19Z\x17neurion/x/sanctum/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'neurion.sanctum.tx_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z\027neurion/x/sanctum/types'
  _globals['_MSGUPDATEPARAMS'].fields_by_name['authority']._loaded_options = None
  _globals['_MSGUPDATEPARAMS'].fields_by_name['authority']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_MSGUPDATEPARAMS'].fields_by_name['params']._loaded_options = None
  _globals['_MSGUPDATEPARAMS'].fields_by_name['params']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_MSGUPDATEPARAMS']._loaded_options = None
  _globals['_MSGUPDATEPARAMS']._serialized_options = b'\202\347\260*\tauthority\212\347\260*!neurion/x/sanctum/MsgUpdateParams'
  _globals['_MSGSUBMITDATASETAPPLICATION']._loaded_options = None
  _globals['_MSGSUBMITDATASETAPPLICATION']._serialized_options = b'\202\347\260*\007creator'
  _globals['_MSGSUBMITDATASETAPPLICATIONRESPONSE'].fields_by_name['dataset_application']._loaded_options = None
  _globals['_MSGSUBMITDATASETAPPLICATIONRESPONSE'].fields_by_name['dataset_application']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_MSGAPPROVEAPPLICATION']._loaded_options = None
  _globals['_MSGAPPROVEAPPLICATION']._serialized_options = b'\202\347\260*\007creator'
  _globals['_MSGREJECTAPPLICATION']._loaded_options = None
  _globals['_MSGREJECTAPPLICATION']._serialized_options = b'\202\347\260*\007creator'
  _globals['_MSGDISCLAIMDATASET']._loaded_options = None
  _globals['_MSGDISCLAIMDATASET']._serialized_options = b'\202\347\260*\007creator'
  _globals['_MSGREQUESTTOUSEDATASET']._loaded_options = None
  _globals['_MSGREQUESTTOUSEDATASET']._serialized_options = b'\202\347\260*\007creator'
  _globals['_MSGREQUESTTOUSEDATASETRESPONSE'].fields_by_name['request']._loaded_options = None
  _globals['_MSGREQUESTTOUSEDATASETRESPONSE'].fields_by_name['request']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_MSGCANCELDATASETUSAGEREQUEST']._loaded_options = None
  _globals['_MSGCANCELDATASETUSAGEREQUEST']._serialized_options = b'\202\347\260*\007creator'
  _globals['_MSGREJECTDATASETUSAGEREQUEST']._loaded_options = None
  _globals['_MSGREJECTDATASETUSAGEREQUEST']._serialized_options = b'\202\347\260*\007creator'
  _globals['_MSGAPPROVEDATASETUSAGEREQUEST']._loaded_options = None
  _globals['_MSGAPPROVEDATASETUSAGEREQUEST']._serialized_options = b'\202\347\260*\007creator'
  _globals['_MSGADDPROCESSOR']._loaded_options = None
  _globals['_MSGADDPROCESSOR']._serialized_options = b'\202\347\260*\007creator'
  _globals['_MSGREMOVEPROCESSOR']._loaded_options = None
  _globals['_MSGREMOVEPROCESSOR']._serialized_options = b'\202\347\260*\007creator'
  _globals['_MSGPROCESSDATASETUSAGEREQUEST']._loaded_options = None
  _globals['_MSGPROCESSDATASETUSAGEREQUEST']._serialized_options = b'\202\347\260*\007creator'
  _globals['_MSGFINISHDATASETUSAGEREQUEST']._loaded_options = None
  _globals['_MSGFINISHDATASETUSAGEREQUEST']._serialized_options = b'\202\347\260*\007creator'
  _globals['_MSGDISPUTEDATASETUSAGEREQUEST']._loaded_options = None
  _globals['_MSGDISPUTEDATASETUSAGEREQUEST']._serialized_options = b'\202\347\260*\007creator'
  _globals['_MSGAPPROVEDISPUTE']._loaded_options = None
  _globals['_MSGAPPROVEDISPUTE']._serialized_options = b'\202\347\260*\007creator'
  _globals['_MSGREJECTDISPUTE']._loaded_options = None
  _globals['_MSGREJECTDISPUTE']._serialized_options = b'\202\347\260*\007creator'
  _globals['_MSGSTAKETOSANCTUM']._loaded_options = None
  _globals['_MSGSTAKETOSANCTUM']._serialized_options = b'\202\347\260*\007creator'
  _globals['_MSGUNSTAKEFROMSANCTUM']._loaded_options = None
  _globals['_MSGUNSTAKEFROMSANCTUM']._serialized_options = b'\202\347\260*\007creator'
  _globals['_MSGCLAIMREWARD']._loaded_options = None
  _globals['_MSGCLAIMREWARD']._serialized_options = b'\202\347\260*\007creator'
  _globals['_MSG']._loaded_options = None
  _globals['_MSG']._serialized_options = b'\200\347\260*\001'
  _globals['_MSGUPDATEPARAMS']._serialized_start=257
  _globals['_MSGUPDATEPARAMS']._serialized_end=425
  _globals['_MSGUPDATEPARAMSRESPONSE']._serialized_start=427
  _globals['_MSGUPDATEPARAMSRESPONSE']._serialized_end=452
  _globals['_MSGSUBMITDATASETAPPLICATION']._serialized_start=455
  _globals['_MSGSUBMITDATASETAPPLICATION']._serialized_end=660
  _globals['_MSGSUBMITDATASETAPPLICATIONRESPONSE']._serialized_start=662
  _globals['_MSGSUBMITDATASETAPPLICATIONRESPONSE']._serialized_end=776
  _globals['_MSGAPPROVEAPPLICATION']._serialized_start=778
  _globals['_MSGAPPROVEAPPLICATION']._serialized_end=872
  _globals['_MSGAPPROVEAPPLICATIONRESPONSE']._serialized_start=874
  _globals['_MSGAPPROVEAPPLICATIONRESPONSE']._serialized_end=905
  _globals['_MSGREJECTAPPLICATION']._serialized_start=907
  _globals['_MSGREJECTAPPLICATION']._serialized_end=1000
  _globals['_MSGREJECTAPPLICATIONRESPONSE']._serialized_start=1002
  _globals['_MSGREJECTAPPLICATIONRESPONSE']._serialized_end=1032
  _globals['_MSGDISCLAIMDATASET']._serialized_start=1034
  _globals['_MSGDISCLAIMDATASET']._serialized_end=1125
  _globals['_MSGDISCLAIMDATASETRESPONSE']._serialized_start=1127
  _globals['_MSGDISCLAIMDATASETRESPONSE']._serialized_end=1155
  _globals['_MSGREQUESTTOUSEDATASET']._serialized_start=1158
  _globals['_MSGREQUESTTOUSEDATASET']._serialized_end=1295
  _globals['_MSGREQUESTTOUSEDATASETRESPONSE']._serialized_start=1297
  _globals['_MSGREQUESTTOUSEDATASETRESPONSE']._serialized_end=1395
  _globals['_MSGCANCELDATASETUSAGEREQUEST']._serialized_start=1397
  _globals['_MSGCANCELDATASETUSAGEREQUEST']._serialized_end=1494
  _globals['_MSGCANCELDATASETUSAGEREQUESTRESPONSE']._serialized_start=1496
  _globals['_MSGCANCELDATASETUSAGEREQUESTRESPONSE']._serialized_end=1534
  _globals['_MSGREJECTDATASETUSAGEREQUEST']._serialized_start=1536
  _globals['_MSGREJECTDATASETUSAGEREQUEST']._serialized_end=1633
  _globals['_MSGREJECTDATASETUSAGEREQUESTRESPONSE']._serialized_start=1635
  _globals['_MSGREJECTDATASETUSAGEREQUESTRESPONSE']._serialized_end=1673
  _globals['_MSGAPPROVEDATASETUSAGEREQUEST']._serialized_start=1675
  _globals['_MSGAPPROVEDATASETUSAGEREQUEST']._serialized_end=1773
  _globals['_MSGAPPROVEDATASETUSAGEREQUESTRESPONSE']._serialized_start=1775
  _globals['_MSGAPPROVEDATASETUSAGEREQUESTRESPONSE']._serialized_end=1814
  _globals['_MSGADDPROCESSOR']._serialized_start=1816
  _globals['_MSGADDPROCESSOR']._serialized_end=1883
  _globals['_MSGADDPROCESSORRESPONSE']._serialized_start=1885
  _globals['_MSGADDPROCESSORRESPONSE']._serialized_end=1910
  _globals['_MSGREMOVEPROCESSOR']._serialized_start=1912
  _globals['_MSGREMOVEPROCESSOR']._serialized_end=1982
  _globals['_MSGREMOVEPROCESSORRESPONSE']._serialized_start=1984
  _globals['_MSGREMOVEPROCESSORRESPONSE']._serialized_end=2012
  _globals['_MSGPROCESSDATASETUSAGEREQUEST']._serialized_start=2014
  _globals['_MSGPROCESSDATASETUSAGEREQUEST']._serialized_end=2096
  _globals['_MSGPROCESSDATASETUSAGEREQUESTRESPONSE']._serialized_start=2098
  _globals['_MSGPROCESSDATASETUSAGEREQUESTRESPONSE']._serialized_end=2137
  _globals['_MSGFINISHDATASETUSAGEREQUEST']._serialized_start=2139
  _globals['_MSGFINISHDATASETUSAGEREQUEST']._serialized_end=2238
  _globals['_MSGFINISHDATASETUSAGEREQUESTRESPONSE']._serialized_start=2240
  _globals['_MSGFINISHDATASETUSAGEREQUESTRESPONSE']._serialized_end=2278
  _globals['_MSGDISPUTEDATASETUSAGEREQUEST']._serialized_start=2280
  _globals['_MSGDISPUTEDATASETUSAGEREQUEST']._serialized_end=2393
  _globals['_MSGDISPUTEDATASETUSAGEREQUESTRESPONSE']._serialized_start=2395
  _globals['_MSGDISPUTEDATASETUSAGEREQUESTRESPONSE']._serialized_end=2434
  _globals['_MSGAPPROVEDISPUTE']._serialized_start=2436
  _globals['_MSGAPPROVEDISPUTE']._serialized_end=2522
  _globals['_MSGAPPROVEDISPUTERESPONSE']._serialized_start=2524
  _globals['_MSGAPPROVEDISPUTERESPONSE']._serialized_end=2551
  _globals['_MSGREJECTDISPUTE']._serialized_start=2553
  _globals['_MSGREJECTDISPUTE']._serialized_end=2638
  _globals['_MSGREJECTDISPUTERESPONSE']._serialized_start=2640
  _globals['_MSGREJECTDISPUTERESPONSE']._serialized_end=2666
  _globals['_MSGSTAKETOSANCTUM']._serialized_start=2668
  _globals['_MSGSTAKETOSANCTUM']._serialized_end=2734
  _globals['_MSGSTAKETOSANCTUMRESPONSE']._serialized_start=2736
  _globals['_MSGSTAKETOSANCTUMRESPONSE']._serialized_end=2763
  _globals['_MSGUNSTAKEFROMSANCTUM']._serialized_start=2765
  _globals['_MSGUNSTAKEFROMSANCTUM']._serialized_end=2835
  _globals['_MSGUNSTAKEFROMSANCTUMRESPONSE']._serialized_start=2837
  _globals['_MSGUNSTAKEFROMSANCTUMRESPONSE']._serialized_end=2868
  _globals['_MSGCLAIMREWARD']._serialized_start=2870
  _globals['_MSGCLAIMREWARD']._serialized_end=2917
  _globals['_MSGCLAIMREWARDRESPONSE']._serialized_start=2919
  _globals['_MSGCLAIMREWARDRESPONSE']._serialized_end=2943
  _globals['_MSG']._serialized_start=2946
  _globals['_MSG']._serialized_end=5093
# @@protoc_insertion_point(module_scope)



from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from typing import ClassVar as _ClassVar

DESCRIPTOR: _descriptor.FileDescriptor

class ErrorCode(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    ErrorCode_NOERROR: _ClassVar[ErrorCode]
    ErrorCode_INVALID_ADDRESS: _ClassVar[ErrorCode]
    ErrorCode_INVALID_TASK_STATUS: _ClassVar[ErrorCode]
    ErrorCode_NOT_TRAINER: _ClassVar[ErrorCode]
    ErrorCode_NOT_SCORER: _ClassVar[ErrorCode]
    ErrorCode_ALREADY_ASSIGNED: _ClassVar[ErrorCode]
    ErrorCode_STAKE_NOT_ENOUGH: _ClassVar[ErrorCode]
    ErrorCode_IN_COOL_DOWN: _ClassVar[ErrorCode]
    ErrorCode_NOT_AUTHORIZED: _ClassVar[ErrorCode]
    ErrorCode_MIN_TIME_NOT_PASSED: _ClassVar[ErrorCode]
    ErrorCode_COLLECTION_ERROR: _ClassVar[ErrorCode]
    ErrorCode_BLACKLISTED: _ClassVar[ErrorCode]
    ErrorCode_ALREADY_SCORER: _ClassVar[ErrorCode]
    ErrorCode_ALREADY_TRAINER: _ClassVar[ErrorCode]
    ErrorCode_ALREADY_SUBMITTED: _ClassVar[ErrorCode]
    ErrorCode_PENDING_DISPUTE: _ClassVar[ErrorCode]
ErrorCode_NOERROR: ErrorCode
ErrorCode_INVALID_ADDRESS: ErrorCode
ErrorCode_INVALID_TASK_STATUS: ErrorCode
ErrorCode_NOT_TRAINER: ErrorCode
ErrorCode_NOT_SCORER: ErrorCode
ErrorCode_ALREADY_ASSIGNED: ErrorCode
ErrorCode_STAKE_NOT_ENOUGH: ErrorCode
ErrorCode_IN_COOL_DOWN: ErrorCode
ErrorCode_NOT_AUTHORIZED: ErrorCode
ErrorCode_MIN_TIME_NOT_PASSED: ErrorCode
ErrorCode_COLLECTION_ERROR: ErrorCode
ErrorCode_BLACKLISTED: ErrorCode
ErrorCode_ALREADY_SCORER: ErrorCode
ErrorCode_ALREADY_TRAINER: ErrorCode
ErrorCode_ALREADY_SUBMITTED: ErrorCode
ErrorCode_PENDING_DISPUTE: ErrorCode



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: cosmos/feegrant/v1beta1/tx.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'cosmos/feegrant/v1beta1/tx.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n cosmos/feegrant/v1beta1/tx.proto\x12\x17\x63osmos.feegrant.v1beta1\x1a\x14gogoproto/gogo.proto\x1a\x19google/protobuf/any.proto\x1a\x19\x63osmos_proto/cosmos.proto\"q\n\x11MsgGrantAllowance\x12\x0f\n\x07granter\x18\x01 \x01(\t\x12\x0f\n\x07grantee\x18\x02 \x01(\t\x12:\n\tallowance\x18\x03 \x01(\x0b\x32\x14.google.protobuf.AnyB\x11\xca\xb4-\rFeeAllowanceI\"\x1b\n\x19MsgGrantAllowanceResponse\"6\n\x12MsgRevokeAllowance\x12\x0f\n\x07granter\x18\x01 \x01(\t\x12\x0f\n\x07grantee\x18\x02 \x01(\t\"\x1c\n\x1aMsgRevokeAllowanceResponse2\xec\x01\n\x03Msg\x12p\n\x0eGrantAllowance\x12*.cosmos.feegrant.v1beta1.MsgGrantAllowance\x1a\x32.cosmos.feegrant.v1beta1.MsgGrantAllowanceResponse\x12s\n\x0fRevokeAllowance\x12+.cosmos.feegrant.v1beta1.MsgRevokeAllowance\x1a\x33.cosmos.feegrant.v1beta1.MsgRevokeAllowanceResponseB)Z\'github.com/cosmos/cosmos-sdk/x/feegrantb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.feegrant.v1beta1.tx_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z\'github.com/cosmos/cosmos-sdk/x/feegrant'
  _globals['_MSGGRANTALLOWANCE'].fields_by_name['allowance']._loaded_options = None
  _globals['_MSGGRANTALLOWANCE'].fields_by_name['allowance']._serialized_options = b'\312\264-\rFeeAllowanceI'
  _globals['_MSGGRANTALLOWANCE']._serialized_start=137
  _globals['_MSGGRANTALLOWANCE']._serialized_end=250
  _globals['_MSGGRANTALLOWANCERESPONSE']._serialized_start=252
  _globals['_MSGGRANTALLOWANCERESPONSE']._serialized_end=279
  _globals['_MSGREVOKEALLOWANCE']._serialized_start=281
  _globals['_MSGREVOKEALLOWANCE']._serialized_end=335
  _globals['_MSGREVOKEALLOWANCERESPONSE']._serialized_start=337
  _globals['_MSGREVOKEALLOWANCERESPONSE']._serialized_end=365
  _globals['_MSG']._serialized_start=368
  _globals['_MSG']._serialized_end=604
# @@protoc_insertion_point(module_scope)



import base64
import json
from typing import List, Optional
from urllib.parse import urlencode

import requests
from google.protobuf.json_format import MessageToDict
from google.protobuf.message import Message


class RestClient:
    """REST api client."""

    def __init__(self, rest_address: str):
        """
        Create REST api client.

        :param rest_address: Address of REST node
        """
        self._session = requests.session()
        self.rest_address = rest_address

    def get(
        self,
        url_base_path: str,
        request: Optional[Message] = None,
        used_params: Optional[List[str]] = None,
    ) -> bytes:
        """
        Send a GET request.

        :param url_base_path: URL base path
        :param request: Protobuf coded request
        :param used_params: Parameters to be removed from request after converting it to dict

        :raises RuntimeError: if response code is not 200

        :return: Content of response
        """
        url = self._make_url(
            url_base_path=url_base_path, request=request, used_params=used_params
        )

        response = self._session.get(url=url)
        if response.status_code != 200:
            raise RuntimeError(
                f"Error when sending a GET request.\n Response: {response.status_code}, {str(response.content)})"
            )
        return response.content

    def _make_url(
        self,
        url_base_path: str,
        request: Optional[Message] = None,
        used_params: Optional[List[str]] = None,
    ) -> str:
        """
        Construct URL for get request.

        :param url_base_path: URL base path
        :param request: Protobuf coded request
        :param used_params: Parameters to be removed from request after converting it to dict

        :return: URL string
        """
        json_request = MessageToDict(request) if request else {}

        # Remove params that are already in url_base_path
        for param in used_params or []:
            json_request.pop(param)

        url_encoded_request = self._url_encode(json_request)

        url = f"{self.rest_address}{url_base_path}"
        if url_encoded_request:
            url = f"{url}?{url_encoded_request}"

        return url

    def post(self, url_base_path: str, request: Message) -> bytes:
        """
        Send a POST request.

        :param url_base_path: URL base path
        :param request: Protobuf coded request

        :raises RuntimeError: if response code is not 200

        :return: Content of response
        """
        json_request = MessageToDict(request)

        # Workaround
        if "tx" in json_request:
            if "body" in json_request["tx"]:
                if "messages" in json_request["tx"]["body"]:
                    for message in json_request["tx"]["body"]["messages"]:
                        if "msg" in message:
                            message["msg"] = json.loads(
                                base64.b64decode(message["msg"])
                            )

        headers = {"Content-type": "application/json", "Accept": "application/json"}
        response = self._session.post(
            url=f"{self.rest_address}{url_base_path}",
            json=json_request,
            headers=headers,
        )

        if response.status_code != 200:
            raise RuntimeError(
                f"Error when sending a POST request.\n Request: {json_request}\n Response: {response.status_code}, {str(response.content)})"
            )
        return response.content

    @staticmethod
    def _url_encode(json_request):
        """A Custom URL encodes that breaks down nested dictionaries to match REST api format.

        It converts dicts from:
        {"pagination": {"limit": "1", "something": "2"},}

        To:
        {"pagination.limit": "1","pagination.something": "2"}


        :param json_request: JSON request

        :return: urlencoded json_request
        """  # noqa: D401
        for outer_k, outer_v in json_request.copy().items():
            if isinstance(outer_v, dict):
                for inner_k, inner_v in outer_v.items():
                    json_request[f"{outer_k}.{inner_k}"] = inner_v
                json_request.pop(outer_k)

        return urlencode(json_request, doseq=True)

    def __del__(self):
        """Destructor method."""
        self._session.close()



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: neurion/crucible/params.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'neurion/crucible/params.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from amino import amino_pb2 as amino_dot_amino__pb2
from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1dneurion/crucible/params.proto\x12\x10neurion.crucible\x1a\x11\x61mino/amino.proto\x1a\x14gogoproto/gogo.proto\"\xbc\x06\n\x06Params\x12\x15\n\radmin_address\x18\x01 \x01(\t\x12!\n\x19min_task_duration_in_days\x18\x02 \x01(\x04\x12\x17\n\x0fmin_task_reward\x18\x03 \x01(\x04\x12\x1e\n\x16min_task_trainer_stake\x18\x04 \x01(\x04\x12\x1d\n\x15min_task_scorer_stake\x18\x05 \x01(\x04\x12\x30\n(submission_cooling_off_period_in_seconds\x18\x06 \x01(\x04\x12%\n\x1dmin_report_plagiarism_deposit\x18\x07 \x01(\x04\x12!\n\x19min_dispute_score_deposit\x18\x08 \x01(\x04\x12\x19\n\x11min_creator_stake\x18\t \x01(\x04\x12\x1f\n\x17\x63reator_application_fee\x18\n \x01(\x04\x12\x1c\n\x14\x64ispute_score_reward\x18\x0b \x01(\x04\x12!\n\x19min_task_training_in_days\x18\x0c \x01(\x04\x12)\n!min_task_final_submission_in_days\x18\r \x01(\x04\x12&\n\x1emin_task_final_dispute_in_days\x18\x0e \x01(\x04\x12\"\n\x1atrainers_reward_percentage\x18\x0f \x01(\x04\x12 \n\x18scorer_reward_percentage\x18\x10 \x01(\x04\x12!\n\x19stakers_reward_percentage\x18\x11 \x01(\x04\x12-\n%trainer_first_place_reward_percentage\x18\x12 \x01(\x04\x12.\n&trainer_second_place_reward_percentage\x18\x13 \x01(\x04\x12-\n%trainer_third_place_reward_percentage\x18\x14 \x01(\x04\x12\x39\n1trainers_number_to_be_rewarded_except_first_three\x18\x15 \x01(\x04:\"\xe8\xa0\x1f\x01\x8a\xe7\xb0*\x19neurion/x/crucible/ParamsB\x1aZ\x18neurion/x/crucible/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'neurion.crucible.params_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z\030neurion/x/crucible/types'
  _globals['_PARAMS']._loaded_options = None
  _globals['_PARAMS']._serialized_options = b'\350\240\037\001\212\347\260*\031neurion/x/crucible/Params'
  _globals['_PARAMS']._serialized_start=93
  _globals['_PARAMS']._serialized_end=921
# @@protoc_insertion_point(module_scope)



from google.protobuf.json_format import Parse

from neurionpy.common.rest_client import RestClient
from neurionpy.protos.neurion.crucible.query_pb2 import (
    QueryParamsRequest, QueryParamsResponse,
    QueryGetCreatorsRequest, QueryGetCreatorsResponse,
    QueryGetCreatorApplicationsRequest, QueryGetCreatorApplicationsResponse,
    QueryGetTaskRequest, QueryGetTaskResponse,
    QueryListAllTasksRequest, QueryListAllTasksResponse,
    QueryListTasksByStatusRequest, QueryListTasksByStatusResponse,
    QueryGetSubmissionRequest, QueryGetSubmissionResponse,
    QueryGetSubmissionByTaskCreatorRequest, QueryGetSubmissionByTaskCreatorResponse,
    QueryGetSubmissionByTaskRequest, QueryGetSubmissionByTaskResponse,
    QueryGetEncryptedProofOfOwnershipRequest, QueryGetEncryptedProofOfOwnershipResponse,
    QueryGetPlagiarismReportRequest, QueryGetPlagiarismReportResponse,
    QueryGetTaskRewardRequest, QueryGetTaskRewardResponse,
    QueryGetPendingCreatorApplicationsRequest, QueryGetPendingCreatorApplicationsResponse,
    QueryGetTaskStakeRequest, QueryGetTaskStakeResponse,
    QueryGetUnscoredSubmissionsByTaskRequest, QueryGetUnscoredSubmissionsByTaskResponse,
    QueryCanTriggerFinalSubmissionRequest, QueryCanTriggerFinalSubmissionResponse,
    QueryCanTriggerFinalTestingRequest, QueryCanTriggerFinalTestingResponse,
    QueryCanRegisterAsTrainerRequest, QueryCanRegisterAsTrainerResponse,
    QueryCanRegisterAsScorerRequest, QueryCanRegisterAsScorerResponse,
    QueryIsTrainerRequest, QueryIsTrainerResponse,
    QueryIsScorerRequest, QueryIsScorerResponse,
    QueryCanSubmitTrainingResultRequest, QueryCanSubmitTrainingResultResponse,
    QueryCanSubmitFinalResultRequest, QueryCanSubmitFinalResultResponse,
    QueryCanRequestScoringTaskRequest, QueryCanRequestScoringTaskResponse,
    QueryGetPendingScoringTasksRequest, QueryGetPendingScoringTasksResponse,
    QueryCanTerminateRequest, QueryCanTerminateResponse,
    QueryGetPlagiarismReportFromUserRequest, QueryGetPlagiarismReportFromUserResponse,
    QueryGetScoreDisputeFromUserRequest, QueryGetScoreDisputeFromUserResponse
)
from neurionpy.crucible.interface import CrucibleQuery


class CrucibleRestClient(CrucibleQuery):
    """Crucible REST client implementing all query endpoints."""
    API_URL = "/neurion/crucible"

    def __init__(self, rest_api: RestClient):
        """
        Initialize the Crucible REST client.

        :param rest_api: RestClient instance for making HTTP requests.
        """
        self._rest_api = rest_api

    def Params(self, request: QueryParamsRequest) -> QueryParamsResponse:
        response = self._rest_api.get(f"{self.API_URL}/params")
        return Parse(response, QueryParamsResponse())

    def GetCreators(self, request: QueryGetCreatorsRequest) -> QueryGetCreatorsResponse:
        response = self._rest_api.get(f"{self.API_URL}/get_creators")
        return Parse(response, QueryGetCreatorsResponse())

    def GetCreatorApplications(self, request: QueryGetCreatorApplicationsRequest) -> QueryGetCreatorApplicationsResponse:
        response = self._rest_api.get(f"{self.API_URL}/get_creator_applications/{request.creator}")
        return Parse(response, QueryGetCreatorApplicationsResponse())

    def GetTask(self, request: QueryGetTaskRequest) -> QueryGetTaskResponse:
        response = self._rest_api.get(f"{self.API_URL}/get_task/{request.id}")
        return Parse(response, QueryGetTaskResponse())

    def ListAllTasks(self, request: QueryListAllTasksRequest) -> QueryListAllTasksResponse:
        response = self._rest_api.get(f"{self.API_URL}/list_all_tasks/{request.offset}/{request.limit}")
        return Parse(response, QueryListAllTasksResponse())

    def ListTasksByStatus(self, request: QueryListTasksByStatusRequest) -> QueryListTasksByStatusResponse:
        response = self._rest_api.get(f"{self.API_URL}/list_tasks_by_status/{request.status}/{request.offset}/{request.limit}")
        return Parse(response, QueryListTasksByStatusResponse())

    def GetSubmission(self, request: QueryGetSubmissionRequest) -> QueryGetSubmissionResponse:
        response = self._rest_api.get(f"{self.API_URL}/get_submission/{request.id}")
        return Parse(response, QueryGetSubmissionResponse())

    def GetSubmissionByTask(self, request: QueryGetSubmissionByTaskRequest) -> QueryGetSubmissionByTaskResponse:
        response = self._rest_api.get(f"{self.API_URL}/get_submission_by_task/{request.task_id}")
        return Parse(response, QueryGetSubmissionByTaskResponse())

    def CanTriggerFinalSubmission(self, request: QueryCanTriggerFinalSubmissionRequest) -> QueryCanTriggerFinalSubmissionResponse:
        response = self._rest_api.get(f"{self.API_URL}/can_trigger_final_submission/{request.creator}/{request.task_id}")
        return Parse(response, QueryCanTriggerFinalSubmissionResponse())

    def CanRegisterAsTrainer(self, request: QueryCanRegisterAsTrainerRequest) -> QueryCanRegisterAsTrainerResponse:
        response = self._rest_api.get(f"{self.API_URL}/can_register_as_trainer/{request.user}/{request.task_id}")
        return Parse(response, QueryCanRegisterAsTrainerResponse())

    def CanSubmitTrainingResult(self, request: QueryCanSubmitTrainingResultRequest) -> QueryCanSubmitTrainingResultResponse:
        response = self._rest_api.get(f"{self.API_URL}/can_submit_training_result/{request.user}/{request.task_id}")
        return Parse(response, QueryCanSubmitTrainingResultResponse())

    def GetPendingScoringTasks(self, request: QueryGetPendingScoringTasksRequest) -> QueryGetPendingScoringTasksResponse:
        response = self._rest_api.get(f"{self.API_URL}/get_pending_scoring_tasks/{request.user}/{request.task_id}")
        return Parse(response, QueryGetPendingScoringTasksResponse())

    def CanTerminate(self, request: QueryCanTerminateRequest) -> QueryCanTerminateResponse:
        response = self._rest_api.get(f"{self.API_URL}/can_terminate/{request.creator}/{request.task_id}")
        return Parse(response, QueryCanTerminateResponse())

    def GetSubmissionByTaskCreator(self, request: QueryGetSubmissionByTaskCreatorRequest) -> QueryGetSubmissionByTaskCreatorResponse:
        response = self._rest_api.get(f"{self.API_URL}/get_submission_by_task_creator/{request.task_id}/{request.creator}")
        return Parse(response, QueryGetSubmissionByTaskCreatorResponse())

    def GetEncryptedProofOfOwnership(self, request: QueryGetEncryptedProofOfOwnershipRequest) -> QueryGetEncryptedProofOfOwnershipResponse:
        response = self._rest_api.get(f"{self.API_URL}/get_encrypted_proof_of_ownership/{request.key}/{request.plaintext}")
        return Parse(response, QueryGetEncryptedProofOfOwnershipResponse())

    def GetPlagiarismReport(self, request: QueryGetPlagiarismReportRequest) -> QueryGetPlagiarismReportResponse:
        response = self._rest_api.get(f"{self.API_URL}/get_plagiarism_report/{request.report_id}")
        return Parse(response, QueryGetPlagiarismReportResponse())

    def GetTaskReward(self, request: QueryGetTaskRewardRequest) -> QueryGetTaskRewardResponse:
        response = self._rest_api.get(f"{self.API_URL}/get_task_reward/{request.task_id}/{request.user}")
        return Parse(response, QueryGetTaskRewardResponse())

    def GetPendingCreatorApplications(self, request: QueryGetPendingCreatorApplicationsRequest) -> QueryGetPendingCreatorApplicationsResponse:
        response = self._rest_api.get(f"{self.API_URL}/get_pending_creator_applications")
        return Parse(response, QueryGetPendingCreatorApplicationsResponse())

    def GetTaskStake(self, request: QueryGetTaskStakeRequest) -> QueryGetTaskStakeResponse:
        response = self._rest_api.get(f"{self.API_URL}/get_task_stake/{request.task_id}/{request.user}")
        return Parse(response, QueryGetTaskStakeResponse())

    def GetUnscoredSubmissionsByTask(self, request: QueryGetUnscoredSubmissionsByTaskRequest) -> QueryGetUnscoredSubmissionsByTaskResponse:
        response = self._rest_api.get(f"{self.API_URL}/get_unscored_submissions_by_task/{request.task_id}")
        return Parse(response, QueryGetUnscoredSubmissionsByTaskResponse())

    def CanTriggerFinalTesting(self, request: QueryCanTriggerFinalTestingRequest) -> QueryCanTriggerFinalTestingResponse:
        response = self._rest_api.get(f"{self.API_URL}/can_trigger_final_testing/{request.creator}/{request.task_id}")
        return Parse(response, QueryCanTriggerFinalTestingResponse())

    def CanRegisterAsScorer(self, request: QueryCanRegisterAsScorerRequest) -> QueryCanRegisterAsScorerResponse:
        response = self._rest_api.get(f"{self.API_URL}/can_register_as_scorer/{request.user}/{request.task_id}")
        return Parse(response, QueryCanRegisterAsScorerResponse())

    def IsTrainer(self, request: QueryIsTrainerRequest) -> QueryIsTrainerResponse:
        response = self._rest_api.get(f"{self.API_URL}/is_trainer/{request.user}/{request.task_id}")
        return Parse(response, QueryIsTrainerResponse())

    def IsScorer(self, request: QueryIsScorerRequest) -> QueryIsScorerResponse:
        response = self._rest_api.get(f"{self.API_URL}/is_scorer/{request.user}/{request.task_id}")
        return Parse(response, QueryIsScorerResponse())

    def CanSubmitFinalResult(self, request: QueryCanSubmitFinalResultRequest) -> QueryCanSubmitFinalResultResponse:
        response = self._rest_api.get(f"{self.API_URL}/can_submit_final_result/{request.user}/{request.task_id}")
        return Parse(response, QueryCanSubmitFinalResultResponse())

    def CanRequestScoringTask(self, request: QueryCanRequestScoringTaskRequest) -> QueryCanRequestScoringTaskResponse:
        response = self._rest_api.get(f"{self.API_URL}/can_request_scoring_task/{request.user}/{request.task_id}")
        return Parse(response, QueryCanRequestScoringTaskResponse())

    def GetPlagiarismReportFromUser(self, request: QueryGetPlagiarismReportFromUserRequest) -> QueryGetPlagiarismReportFromUserResponse:
        """Queries a list of plagiarism reports submitted by a specific user."""
        response = self._rest_api.get(f"{self.API_URL}/get_plagiarism_report_from_user/{request.user}")
        return Parse(response, QueryGetPlagiarismReportFromUserResponse())

    def GetScoreDisputeFromUser(self, request: QueryGetScoreDisputeFromUserRequest) -> QueryGetScoreDisputeFromUserResponse:
        """Queries a list of score disputes raised by a specific user."""
        response = self._rest_api.get(f"{self.API_URL}/get_score_dispute_from_user/{request.user}")
        return Parse(response, QueryGetScoreDisputeFromUserResponse())



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: cosmos/authz/v1beta1/event.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'cosmos/authz/v1beta1/event.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n cosmos/authz/v1beta1/event.proto\x12\x14\x63osmos.authz.v1beta1\"D\n\nEventGrant\x12\x14\n\x0cmsg_type_url\x18\x02 \x01(\t\x12\x0f\n\x07granter\x18\x03 \x01(\t\x12\x0f\n\x07grantee\x18\x04 \x01(\t\"E\n\x0b\x45ventRevoke\x12\x14\n\x0cmsg_type_url\x18\x02 \x01(\t\x12\x0f\n\x07granter\x18\x03 \x01(\t\x12\x0f\n\x07grantee\x18\x04 \x01(\tB&Z$github.com/cosmos/cosmos-sdk/x/authzb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.authz.v1beta1.event_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z$github.com/cosmos/cosmos-sdk/x/authz'
  _globals['_EVENTGRANT']._serialized_start=58
  _globals['_EVENTGRANT']._serialized_end=126
  _globals['_EVENTREVOKE']._serialized_start=128
  _globals['_EVENTREVOKE']._serialized_end=197
# @@protoc_insertion_point(module_scope)



from abc import ABC, abstractmethod

from neurionpy.protos.ibc.core.client.v1.query_pb2 import (
    QueryClientParamsRequest,
    QueryClientParamsResponse,
    QueryClientStateRequest,
    QueryClientStateResponse,
    QueryClientStatesRequest,
    QueryClientStatesResponse,
    QueryConsensusStateRequest,
    QueryConsensusStateResponse,
    QueryConsensusStatesRequest,
    QueryConsensusStatesResponse,
)


class IBCCoreClient(ABC):
    """IBC Core Client abstract class."""

    @abstractmethod
    def ClientState(self, request: QueryClientStateRequest) -> QueryClientStateResponse:
        """
        ClientState queries an IBC light client.

        :param request: QueryClientStateRequest
        :return: QueryClientStateResponse
        """

    @abstractmethod
    def ClientStates(
        self, request: QueryClientStatesRequest
    ) -> QueryClientStatesResponse:
        """
        ClientStates queries all the IBC light clients of a chain.

        :param request: QueryClientStatesRequest
        :return: QueryClientStatesResponse
        """

    @abstractmethod
    def ConsensusState(
        self, request: QueryConsensusStateRequest
    ) -> QueryConsensusStateResponse:
        """
        ConsensusState queries a consensus state associated with a client state at a given height.

        :param request: QueryConsensusStateRequest
        :return: QueryConsensusStateResponse
        """

    @abstractmethod
    def ConsensusStates(
        self, request: QueryConsensusStatesRequest
    ) -> QueryConsensusStatesResponse:
        """
        ConsensusStates queries all the consensus states associated with a given client.

        :param request: QueryConsensusStatesRequest
        :return: QueryConsensusStatesResponse
        """

    @abstractmethod
    def ClientParams(
        self, request: QueryClientParamsRequest
    ) -> QueryClientParamsResponse:
        """
        ClientParams queries all parameters of the IBC client.

        :param request: QueryClientParamsRequest
        :return: QueryClientParamsResponse
        """



from google.protobuf import descriptor_pb2 as _descriptor_pb2
from google.protobuf import descriptor as _descriptor
from typing import ClassVar as _ClassVar

DESCRIPTOR: _descriptor.FileDescriptor
SERVICE_FIELD_NUMBER: _ClassVar[int]
service: _descriptor.FieldDescriptor
SIGNER_FIELD_NUMBER: _ClassVar[int]
signer: _descriptor.FieldDescriptor



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: cosmos/params/v1beta1/query.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'cosmos/params/v1beta1/query.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from cosmos.params.v1beta1 import params_pb2 as cosmos_dot_params_dot_v1beta1_dot_params__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!cosmos/params/v1beta1/query.proto\x12\x15\x63osmos.params.v1beta1\x1a\x14gogoproto/gogo.proto\x1a\x1cgoogle/api/annotations.proto\x1a\"cosmos/params/v1beta1/params.proto\"3\n\x12QueryParamsRequest\x12\x10\n\x08subspace\x18\x01 \x01(\t\x12\x0b\n\x03key\x18\x02 \x01(\t\"N\n\x13QueryParamsResponse\x12\x37\n\x05param\x18\x01 \x01(\x0b\x32\".cosmos.params.v1beta1.ParamChangeB\x04\xc8\xde\x1f\x00\x32\x90\x01\n\x05Query\x12\x86\x01\n\x06Params\x12).cosmos.params.v1beta1.QueryParamsRequest\x1a*.cosmos.params.v1beta1.QueryParamsResponse\"%\x82\xd3\xe4\x93\x02\x1f\x12\x1d/cosmos/params/v1beta1/paramsB6Z4github.com/cosmos/cosmos-sdk/x/params/types/proposalb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.params.v1beta1.query_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z4github.com/cosmos/cosmos-sdk/x/params/types/proposal'
  _globals['_QUERYPARAMSRESPONSE'].fields_by_name['param']._loaded_options = None
  _globals['_QUERYPARAMSRESPONSE'].fields_by_name['param']._serialized_options = b'\310\336\037\000'
  _globals['_QUERY'].methods_by_name['Params']._loaded_options = None
  _globals['_QUERY'].methods_by_name['Params']._serialized_options = b'\202\323\344\223\002\037\022\035/cosmos/params/v1beta1/params'
  _globals['_QUERYPARAMSREQUEST']._serialized_start=148
  _globals['_QUERYPARAMSREQUEST']._serialized_end=199
  _globals['_QUERYPARAMSRESPONSE']._serialized_start=201
  _globals['_QUERYPARAMSRESPONSE']._serialized_end=279
  _globals['_QUERY']._serialized_start=282
  _globals['_QUERY']._serialized_end=426
# @@protoc_insertion_point(module_scope)



from google.protobuf.json_format import Parse
from neurionpy.common.rest_client import RestClient
from neurionpy.protos.neurion.sanctum.query_pb2 import (
    QueryParamsRequest, QueryParamsResponse,
    QueryGetAvailableDatasetsRequest, QueryGetAvailableDatasetsResponse,
    QueryGetApprovedUsageRequestsRequest, QueryGetApprovedUsageRequestsResponse,
    QueryGetRewardRequest, QueryGetRewardResponse,
    QueryGetStakeRequest, QueryGetStakeResponse,
    QueryGetPendingDatasetsRequest, QueryGetPendingDatasetsResponse,
    QueryGetPendingUsageRequestsRequest, QueryGetPendingUsageRequestsResponse,
    QueryGetDatasetRequest, QueryGetDatasetResponse,
    QueryGetUsageRequestRequest, QueryGetUsageRequestResponse,
    QueryGetUsageRequestsForDatasetRequest, QueryGetUsageRequestsForDatasetResponse,
    QueryGetUsageRequestsForUserRequest, QueryGetUsageRequestsForUserResponse,
    QueryGetDatasetsForUserRequest, QueryGetDatasetsForUserResponse
)
from neurionpy.sanctum.interface import SanctumQuery

class SanctumRestClient(SanctumQuery):
    """Sanctum REST client implementing all query endpoints."""
    API_URL = "/neurion/sanctum"

    def __init__(self, rest_api: RestClient):
        """
        Create Sanctum REST client.

        :param rest_api: RestClient instance for making HTTP requests.
        """
        self._rest_api = rest_api

    def Params(self, request: QueryParamsRequest) -> QueryParamsResponse:
        response = self._rest_api.get(f"{self.API_URL}/params")
        return Parse(response, QueryParamsResponse())

    def GetAvailableDatasets(self, request: QueryGetAvailableDatasetsRequest) -> QueryGetAvailableDatasetsResponse:
        params = {"offset": request.offset, "limit": request.limit}
        response = self._rest_api.get(f"{self.API_URL}/get_available_datasets", params=params)
        return Parse(response, QueryGetAvailableDatasetsResponse())

    def GetApprovedUsageRequests(self, request: QueryGetApprovedUsageRequestsRequest) -> QueryGetApprovedUsageRequestsResponse:
        response = self._rest_api.get(f"{self.API_URL}/get_approved_usage_requests")
        return Parse(response, QueryGetApprovedUsageRequestsResponse())

    def GetReward(self, request: QueryGetRewardRequest) -> QueryGetRewardResponse:
        response = self._rest_api.get(f"{self.API_URL}/get_reward/{request.user}")
        return Parse(response, QueryGetRewardResponse())

    def GetStake(self, request: QueryGetStakeRequest) -> QueryGetStakeResponse:
        response = self._rest_api.get(f"{self.API_URL}/get_stake/{request.user}")
        return Parse(response, QueryGetStakeResponse())

    def GetPendingDatasets(self, request: QueryGetPendingDatasetsRequest) -> QueryGetPendingDatasetsResponse:
        response = self._rest_api.get(f"{self.API_URL}/get_pending_datasets")
        return Parse(response, QueryGetPendingDatasetsResponse())

    def GetPendingUsageRequests(self, request: QueryGetPendingUsageRequestsRequest) -> QueryGetPendingUsageRequestsResponse:
        response = self._rest_api.get(f"{self.API_URL}/get_pending_usage_requests/{request.user}")
        return Parse(response, QueryGetPendingUsageRequestsResponse())

    def GetDataset(self, request: QueryGetDatasetRequest) -> QueryGetDatasetResponse:
        response = self._rest_api.get(f"{self.API_URL}/get_dataset/{request.id}")
        return Parse(response, QueryGetDatasetResponse())

    def GetUsageRequest(self, request: QueryGetUsageRequestRequest) -> QueryGetUsageRequestResponse:
        response = self._rest_api.get(f"{self.API_URL}/get_usage_request/{request.id}")
        return Parse(response, QueryGetUsageRequestResponse())

    def GetUsageRequestsForDataset(self, request: QueryGetUsageRequestsForDatasetRequest) -> QueryGetUsageRequestsForDatasetResponse:
        response = self._rest_api.get(f"{self.API_URL}/get_usage_requests_for_dataset/{request.dataset_id}/{request.offset}/{request.limit}")
        return Parse(response, QueryGetUsageRequestsForDatasetResponse())

    def GetUsageRequestsForUser(self, request: QueryGetUsageRequestsForUserRequest) -> QueryGetUsageRequestsForUserResponse:
        response = self._rest_api.get(f"{self.API_URL}/get_usage_requests_for_user/{request.user}/{request.offset}/{request.limit}")
        return Parse(response, QueryGetUsageRequestsForUserResponse())

    def GetDatasetsForUser(self, request: QueryGetDatasetsForUserRequest) -> QueryGetDatasetsForUserResponse:
        response = self._rest_api.get(f"{self.API_URL}/get_datasets_for_user/{request.user}/{request.offset}/{request.limit}")
        return Parse(response, QueryGetDatasetsForUserResponse())



from cometbft.crypto.v1 import keys_pb2 as _keys_pb2
from cometbft.crypto.v1 import proof_pb2 as _proof_pb2
from cometbft.types.v1beta1 import params_pb2 as _params_pb2
from cometbft.types.v1beta1 import types_pb2 as _types_pb2
from gogoproto import gogo_pb2 as _gogo_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class CheckTxType(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    NEW: _ClassVar[CheckTxType]
    RECHECK: _ClassVar[CheckTxType]

class EvidenceType(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    UNKNOWN: _ClassVar[EvidenceType]
    DUPLICATE_VOTE: _ClassVar[EvidenceType]
    LIGHT_CLIENT_ATTACK: _ClassVar[EvidenceType]
NEW: CheckTxType
RECHECK: CheckTxType
UNKNOWN: EvidenceType
DUPLICATE_VOTE: EvidenceType
LIGHT_CLIENT_ATTACK: EvidenceType

class Request(_message.Message):
    __slots__ = ("echo", "flush", "info", "set_option", "init_chain", "query", "begin_block", "check_tx", "deliver_tx", "end_block", "commit", "list_snapshots", "offer_snapshot", "load_snapshot_chunk", "apply_snapshot_chunk")
    ECHO_FIELD_NUMBER: _ClassVar[int]
    FLUSH_FIELD_NUMBER: _ClassVar[int]
    INFO_FIELD_NUMBER: _ClassVar[int]
    SET_OPTION_FIELD_NUMBER: _ClassVar[int]
    INIT_CHAIN_FIELD_NUMBER: _ClassVar[int]
    QUERY_FIELD_NUMBER: _ClassVar[int]
    BEGIN_BLOCK_FIELD_NUMBER: _ClassVar[int]
    CHECK_TX_FIELD_NUMBER: _ClassVar[int]
    DELIVER_TX_FIELD_NUMBER: _ClassVar[int]
    END_BLOCK_FIELD_NUMBER: _ClassVar[int]
    COMMIT_FIELD_NUMBER: _ClassVar[int]
    LIST_SNAPSHOTS_FIELD_NUMBER: _ClassVar[int]
    OFFER_SNAPSHOT_FIELD_NUMBER: _ClassVar[int]
    LOAD_SNAPSHOT_CHUNK_FIELD_NUMBER: _ClassVar[int]
    APPLY_SNAPSHOT_CHUNK_FIELD_NUMBER: _ClassVar[int]
    echo: RequestEcho
    flush: RequestFlush
    info: RequestInfo
    set_option: RequestSetOption
    init_chain: RequestInitChain
    query: RequestQuery
    begin_block: RequestBeginBlock
    check_tx: RequestCheckTx
    deliver_tx: RequestDeliverTx
    end_block: RequestEndBlock
    commit: RequestCommit
    list_snapshots: RequestListSnapshots
    offer_snapshot: RequestOfferSnapshot
    load_snapshot_chunk: RequestLoadSnapshotChunk
    apply_snapshot_chunk: RequestApplySnapshotChunk
    def __init__(self, echo: _Optional[_Union[RequestEcho, _Mapping]] = ..., flush: _Optional[_Union[RequestFlush, _Mapping]] = ..., info: _Optional[_Union[RequestInfo, _Mapping]] = ..., set_option: _Optional[_Union[RequestSetOption, _Mapping]] = ..., init_chain: _Optional[_Union[RequestInitChain, _Mapping]] = ..., query: _Optional[_Union[RequestQuery, _Mapping]] = ..., begin_block: _Optional[_Union[RequestBeginBlock, _Mapping]] = ..., check_tx: _Optional[_Union[RequestCheckTx, _Mapping]] = ..., deliver_tx: _Optional[_Union[RequestDeliverTx, _Mapping]] = ..., end_block: _Optional[_Union[RequestEndBlock, _Mapping]] = ..., commit: _Optional[_Union[RequestCommit, _Mapping]] = ..., list_snapshots: _Optional[_Union[RequestListSnapshots, _Mapping]] = ..., offer_snapshot: _Optional[_Union[RequestOfferSnapshot, _Mapping]] = ..., load_snapshot_chunk: _Optional[_Union[RequestLoadSnapshotChunk, _Mapping]] = ..., apply_snapshot_chunk: _Optional[_Union[RequestApplySnapshotChunk, _Mapping]] = ...) -> None: ...

class RequestEcho(_message.Message):
    __slots__ = ("message",)
    MESSAGE_FIELD_NUMBER: _ClassVar[int]
    message: str
    def __init__(self, message: _Optional[str] = ...) -> None: ...

class RequestFlush(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class RequestInfo(_message.Message):
    __slots__ = ("version", "block_version", "p2p_version")
    VERSION_FIELD_NUMBER: _ClassVar[int]
    BLOCK_VERSION_FIELD_NUMBER: _ClassVar[int]
    P2P_VERSION_FIELD_NUMBER: _ClassVar[int]
    version: str
    block_version: int
    p2p_version: int
    def __init__(self, version: _Optional[str] = ..., block_version: _Optional[int] = ..., p2p_version: _Optional[int] = ...) -> None: ...

class RequestSetOption(_message.Message):
    __slots__ = ("key", "value")
    KEY_FIELD_NUMBER: _ClassVar[int]
    VALUE_FIELD_NUMBER: _ClassVar[int]
    key: str
    value: str
    def __init__(self, key: _Optional[str] = ..., value: _Optional[str] = ...) -> None: ...

class RequestInitChain(_message.Message):
    __slots__ = ("time", "chain_id", "consensus_params", "validators", "app_state_bytes", "initial_height")
    TIME_FIELD_NUMBER: _ClassVar[int]
    CHAIN_ID_FIELD_NUMBER: _ClassVar[int]
    CONSENSUS_PARAMS_FIELD_NUMBER: _ClassVar[int]
    VALIDATORS_FIELD_NUMBER: _ClassVar[int]
    APP_STATE_BYTES_FIELD_NUMBER: _ClassVar[int]
    INITIAL_HEIGHT_FIELD_NUMBER: _ClassVar[int]
    time: _timestamp_pb2.Timestamp
    chain_id: str
    consensus_params: ConsensusParams
    validators: _containers.RepeatedCompositeFieldContainer[ValidatorUpdate]
    app_state_bytes: bytes
    initial_height: int
    def __init__(self, time: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., chain_id: _Optional[str] = ..., consensus_params: _Optional[_Union[ConsensusParams, _Mapping]] = ..., validators: _Optional[_Iterable[_Union[ValidatorUpdate, _Mapping]]] = ..., app_state_bytes: _Optional[bytes] = ..., initial_height: _Optional[int] = ...) -> None: ...

class RequestQuery(_message.Message):
    __slots__ = ("data", "path", "height", "prove")
    DATA_FIELD_NUMBER: _ClassVar[int]
    PATH_FIELD_NUMBER: _ClassVar[int]
    HEIGHT_FIELD_NUMBER: _ClassVar[int]
    PROVE_FIELD_NUMBER: _ClassVar[int]
    data: bytes
    path: str
    height: int
    prove: bool
    def __init__(self, data: _Optional[bytes] = ..., path: _Optional[str] = ..., height: _Optional[int] = ..., prove: bool = ...) -> None: ...

class RequestBeginBlock(_message.Message):
    __slots__ = ("hash", "header", "last_commit_info", "byzantine_validators")
    HASH_FIELD_NUMBER: _ClassVar[int]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    LAST_COMMIT_INFO_FIELD_NUMBER: _ClassVar[int]
    BYZANTINE_VALIDATORS_FIELD_NUMBER: _ClassVar[int]
    hash: bytes
    header: _types_pb2.Header
    last_commit_info: LastCommitInfo
    byzantine_validators: _containers.RepeatedCompositeFieldContainer[Evidence]
    def __init__(self, hash: _Optional[bytes] = ..., header: _Optional[_Union[_types_pb2.Header, _Mapping]] = ..., last_commit_info: _Optional[_Union[LastCommitInfo, _Mapping]] = ..., byzantine_validators: _Optional[_Iterable[_Union[Evidence, _Mapping]]] = ...) -> None: ...

class RequestCheckTx(_message.Message):
    __slots__ = ("tx", "type")
    TX_FIELD_NUMBER: _ClassVar[int]
    TYPE_FIELD_NUMBER: _ClassVar[int]
    tx: bytes
    type: CheckTxType
    def __init__(self, tx: _Optional[bytes] = ..., type: _Optional[_Union[CheckTxType, str]] = ...) -> None: ...

class RequestDeliverTx(_message.Message):
    __slots__ = ("tx",)
    TX_FIELD_NUMBER: _ClassVar[int]
    tx: bytes
    def __init__(self, tx: _Optional[bytes] = ...) -> None: ...

class RequestEndBlock(_message.Message):
    __slots__ = ("height",)
    HEIGHT_FIELD_NUMBER: _ClassVar[int]
    height: int
    def __init__(self, height: _Optional[int] = ...) -> None: ...

class RequestCommit(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class RequestListSnapshots(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class RequestOfferSnapshot(_message.Message):
    __slots__ = ("snapshot", "app_hash")
    SNAPSHOT_FIELD_NUMBER: _ClassVar[int]
    APP_HASH_FIELD_NUMBER: _ClassVar[int]
    snapshot: Snapshot
    app_hash: bytes
    def __init__(self, snapshot: _Optional[_Union[Snapshot, _Mapping]] = ..., app_hash: _Optional[bytes] = ...) -> None: ...

class RequestLoadSnapshotChunk(_message.Message):
    __slots__ = ("height", "format", "chunk")
    HEIGHT_FIELD_NUMBER: _ClassVar[int]
    FORMAT_FIELD_NUMBER: _ClassVar[int]
    CHUNK_FIELD_NUMBER: _ClassVar[int]
    height: int
    format: int
    chunk: int
    def __init__(self, height: _Optional[int] = ..., format: _Optional[int] = ..., chunk: _Optional[int] = ...) -> None: ...

class RequestApplySnapshotChunk(_message.Message):
    __slots__ = ("index", "chunk", "sender")
    INDEX_FIELD_NUMBER: _ClassVar[int]
    CHUNK_FIELD_NUMBER: _ClassVar[int]
    SENDER_FIELD_NUMBER: _ClassVar[int]
    index: int
    chunk: bytes
    sender: str
    def __init__(self, index: _Optional[int] = ..., chunk: _Optional[bytes] = ..., sender: _Optional[str] = ...) -> None: ...

class Response(_message.Message):
    __slots__ = ("exception", "echo", "flush", "info", "set_option", "init_chain", "query", "begin_block", "check_tx", "deliver_tx", "end_block", "commit", "list_snapshots", "offer_snapshot", "load_snapshot_chunk", "apply_snapshot_chunk")
    EXCEPTION_FIELD_NUMBER: _ClassVar[int]
    ECHO_FIELD_NUMBER: _ClassVar[int]
    FLUSH_FIELD_NUMBER: _ClassVar[int]
    INFO_FIELD_NUMBER: _ClassVar[int]
    SET_OPTION_FIELD_NUMBER: _ClassVar[int]
    INIT_CHAIN_FIELD_NUMBER: _ClassVar[int]
    QUERY_FIELD_NUMBER: _ClassVar[int]
    BEGIN_BLOCK_FIELD_NUMBER: _ClassVar[int]
    CHECK_TX_FIELD_NUMBER: _ClassVar[int]
    DELIVER_TX_FIELD_NUMBER: _ClassVar[int]
    END_BLOCK_FIELD_NUMBER: _ClassVar[int]
    COMMIT_FIELD_NUMBER: _ClassVar[int]
    LIST_SNAPSHOTS_FIELD_NUMBER: _ClassVar[int]
    OFFER_SNAPSHOT_FIELD_NUMBER: _ClassVar[int]
    LOAD_SNAPSHOT_CHUNK_FIELD_NUMBER: _ClassVar[int]
    APPLY_SNAPSHOT_CHUNK_FIELD_NUMBER: _ClassVar[int]
    exception: ResponseException
    echo: ResponseEcho
    flush: ResponseFlush
    info: ResponseInfo
    set_option: ResponseSetOption
    init_chain: ResponseInitChain
    query: ResponseQuery
    begin_block: ResponseBeginBlock
    check_tx: ResponseCheckTx
    deliver_tx: ResponseDeliverTx
    end_block: ResponseEndBlock
    commit: ResponseCommit
    list_snapshots: ResponseListSnapshots
    offer_snapshot: ResponseOfferSnapshot
    load_snapshot_chunk: ResponseLoadSnapshotChunk
    apply_snapshot_chunk: ResponseApplySnapshotChunk
    def __init__(self, exception: _Optional[_Union[ResponseException, _Mapping]] = ..., echo: _Optional[_Union[ResponseEcho, _Mapping]] = ..., flush: _Optional[_Union[ResponseFlush, _Mapping]] = ..., info: _Optional[_Union[ResponseInfo, _Mapping]] = ..., set_option: _Optional[_Union[ResponseSetOption, _Mapping]] = ..., init_chain: _Optional[_Union[ResponseInitChain, _Mapping]] = ..., query: _Optional[_Union[ResponseQuery, _Mapping]] = ..., begin_block: _Optional[_Union[ResponseBeginBlock, _Mapping]] = ..., check_tx: _Optional[_Union[ResponseCheckTx, _Mapping]] = ..., deliver_tx: _Optional[_Union[ResponseDeliverTx, _Mapping]] = ..., end_block: _Optional[_Union[ResponseEndBlock, _Mapping]] = ..., commit: _Optional[_Union[ResponseCommit, _Mapping]] = ..., list_snapshots: _Optional[_Union[ResponseListSnapshots, _Mapping]] = ..., offer_snapshot: _Optional[_Union[ResponseOfferSnapshot, _Mapping]] = ..., load_snapshot_chunk: _Optional[_Union[ResponseLoadSnapshotChunk, _Mapping]] = ..., apply_snapshot_chunk: _Optional[_Union[ResponseApplySnapshotChunk, _Mapping]] = ...) -> None: ...

class ResponseException(_message.Message):
    __slots__ = ("error",)
    ERROR_FIELD_NUMBER: _ClassVar[int]
    error: str
    def __init__(self, error: _Optional[str] = ...) -> None: ...

class ResponseEcho(_message.Message):
    __slots__ = ("message",)
    MESSAGE_FIELD_NUMBER: _ClassVar[int]
    message: str
    def __init__(self, message: _Optional[str] = ...) -> None: ...

class ResponseFlush(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class ResponseInfo(_message.Message):
    __slots__ = ("data", "version", "app_version", "last_block_height", "last_block_app_hash")
    DATA_FIELD_NUMBER: _ClassVar[int]
    VERSION_FIELD_NUMBER: _ClassVar[int]
    APP_VERSION_FIELD_NUMBER: _ClassVar[int]
    LAST_BLOCK_HEIGHT_FIELD_NUMBER: _ClassVar[int]
    LAST_BLOCK_APP_HASH_FIELD_NUMBER: _ClassVar[int]
    data: str
    version: str
    app_version: int
    last_block_height: int
    last_block_app_hash: bytes
    def __init__(self, data: _Optional[str] = ..., version: _Optional[str] = ..., app_version: _Optional[int] = ..., last_block_height: _Optional[int] = ..., last_block_app_hash: _Optional[bytes] = ...) -> None: ...

class ResponseSetOption(_message.Message):
    __slots__ = ("code", "log", "info")
    CODE_FIELD_NUMBER: _ClassVar[int]
    LOG_FIELD_NUMBER: _ClassVar[int]
    INFO_FIELD_NUMBER: _ClassVar[int]
    code: int
    log: str
    info: str
    def __init__(self, code: _Optional[int] = ..., log: _Optional[str] = ..., info: _Optional[str] = ...) -> None: ...

class ResponseInitChain(_message.Message):
    __slots__ = ("consensus_params", "validators", "app_hash")
    CONSENSUS_PARAMS_FIELD_NUMBER: _ClassVar[int]
    VALIDATORS_FIELD_NUMBER: _ClassVar[int]
    APP_HASH_FIELD_NUMBER: _ClassVar[int]
    consensus_params: ConsensusParams
    validators: _containers.RepeatedCompositeFieldContainer[ValidatorUpdate]
    app_hash: bytes
    def __init__(self, consensus_params: _Optional[_Union[ConsensusParams, _Mapping]] = ..., validators: _Optional[_Iterable[_Union[ValidatorUpdate, _Mapping]]] = ..., app_hash: _Optional[bytes] = ...) -> None: ...

class ResponseQuery(_message.Message):
    __slots__ = ("code", "log", "info", "index", "key", "value", "proof_ops", "height", "codespace")
    CODE_FIELD_NUMBER: _ClassVar[int]
    LOG_FIELD_NUMBER: _ClassVar[int]
    INFO_FIELD_NUMBER: _ClassVar[int]
    INDEX_FIELD_NUMBER: _ClassVar[int]
    KEY_FIELD_NUMBER: _ClassVar[int]
    VALUE_FIELD_NUMBER: _ClassVar[int]
    PROOF_OPS_FIELD_NUMBER: _ClassVar[int]
    HEIGHT_FIELD_NUMBER: _ClassVar[int]
    CODESPACE_FIELD_NUMBER: _ClassVar[int]
    code: int
    log: str
    info: str
    index: int
    key: bytes
    value: bytes
    proof_ops: _proof_pb2.ProofOps
    height: int
    codespace: str
    def __init__(self, code: _Optional[int] = ..., log: _Optional[str] = ..., info: _Optional[str] = ..., index: _Optional[int] = ..., key: _Optional[bytes] = ..., value: _Optional[bytes] = ..., proof_ops: _Optional[_Union[_proof_pb2.ProofOps, _Mapping]] = ..., height: _Optional[int] = ..., codespace: _Optional[str] = ...) -> None: ...

class ResponseBeginBlock(_message.Message):
    __slots__ = ("events",)
    EVENTS_FIELD_NUMBER: _ClassVar[int]
    events: _containers.RepeatedCompositeFieldContainer[Event]
    def __init__(self, events: _Optional[_Iterable[_Union[Event, _Mapping]]] = ...) -> None: ...

class ResponseCheckTx(_message.Message):
    __slots__ = ("code", "data", "log", "info", "gas_wanted", "gas_used", "events", "codespace", "sender", "priority", "mempool_error")
    CODE_FIELD_NUMBER: _ClassVar[int]
    DATA_FIELD_NUMBER: _ClassVar[int]
    LOG_FIELD_NUMBER: _ClassVar[int]
    INFO_FIELD_NUMBER: _ClassVar[int]
    GAS_WANTED_FIELD_NUMBER: _ClassVar[int]
    GAS_USED_FIELD_NUMBER: _ClassVar[int]
    EVENTS_FIELD_NUMBER: _ClassVar[int]
    CODESPACE_FIELD_NUMBER: _ClassVar[int]
    SENDER_FIELD_NUMBER: _ClassVar[int]
    PRIORITY_FIELD_NUMBER: _ClassVar[int]
    MEMPOOL_ERROR_FIELD_NUMBER: _ClassVar[int]
    code: int
    data: bytes
    log: str
    info: str
    gas_wanted: int
    gas_used: int
    events: _containers.RepeatedCompositeFieldContainer[Event]
    codespace: str
    sender: str
    priority: int
    mempool_error: str
    def __init__(self, code: _Optional[int] = ..., data: _Optional[bytes] = ..., log: _Optional[str] = ..., info: _Optional[str] = ..., gas_wanted: _Optional[int] = ..., gas_used: _Optional[int] = ..., events: _Optional[_Iterable[_Union[Event, _Mapping]]] = ..., codespace: _Optional[str] = ..., sender: _Optional[str] = ..., priority: _Optional[int] = ..., mempool_error: _Optional[str] = ...) -> None: ...

class ResponseDeliverTx(_message.Message):
    __slots__ = ("code", "data", "log", "info", "gas_wanted", "gas_used", "events", "codespace")
    CODE_FIELD_NUMBER: _ClassVar[int]
    DATA_FIELD_NUMBER: _ClassVar[int]
    LOG_FIELD_NUMBER: _ClassVar[int]
    INFO_FIELD_NUMBER: _ClassVar[int]
    GAS_WANTED_FIELD_NUMBER: _ClassVar[int]
    GAS_USED_FIELD_NUMBER: _ClassVar[int]
    EVENTS_FIELD_NUMBER: _ClassVar[int]
    CODESPACE_FIELD_NUMBER: _ClassVar[int]
    code: int
    data: bytes
    log: str
    info: str
    gas_wanted: int
    gas_used: int
    events: _containers.RepeatedCompositeFieldContainer[Event]
    codespace: str
    def __init__(self, code: _Optional[int] = ..., data: _Optional[bytes] = ..., log: _Optional[str] = ..., info: _Optional[str] = ..., gas_wanted: _Optional[int] = ..., gas_used: _Optional[int] = ..., events: _Optional[_Iterable[_Union[Event, _Mapping]]] = ..., codespace: _Optional[str] = ...) -> None: ...

class ResponseEndBlock(_message.Message):
    __slots__ = ("validator_updates", "consensus_param_updates", "events")
    VALIDATOR_UPDATES_FIELD_NUMBER: _ClassVar[int]
    CONSENSUS_PARAM_UPDATES_FIELD_NUMBER: _ClassVar[int]
    EVENTS_FIELD_NUMBER: _ClassVar[int]
    validator_updates: _containers.RepeatedCompositeFieldContainer[ValidatorUpdate]
    consensus_param_updates: ConsensusParams
    events: _containers.RepeatedCompositeFieldContainer[Event]
    def __init__(self, validator_updates: _Optional[_Iterable[_Union[ValidatorUpdate, _Mapping]]] = ..., consensus_param_updates: _Optional[_Union[ConsensusParams, _Mapping]] = ..., events: _Optional[_Iterable[_Union[Event, _Mapping]]] = ...) -> None: ...

class ResponseCommit(_message.Message):
    __slots__ = ("data", "retain_height")
    DATA_FIELD_NUMBER: _ClassVar[int]
    RETAIN_HEIGHT_FIELD_NUMBER: _ClassVar[int]
    data: bytes
    retain_height: int
    def __init__(self, data: _Optional[bytes] = ..., retain_height: _Optional[int] = ...) -> None: ...

class ResponseListSnapshots(_message.Message):
    __slots__ = ("snapshots",)
    SNAPSHOTS_FIELD_NUMBER: _ClassVar[int]
    snapshots: _containers.RepeatedCompositeFieldContainer[Snapshot]
    def __init__(self, snapshots: _Optional[_Iterable[_Union[Snapshot, _Mapping]]] = ...) -> None: ...

class ResponseOfferSnapshot(_message.Message):
    __slots__ = ("result",)
    class Result(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        UNKNOWN: _ClassVar[ResponseOfferSnapshot.Result]
        ACCEPT: _ClassVar[ResponseOfferSnapshot.Result]
        ABORT: _ClassVar[ResponseOfferSnapshot.Result]
        REJECT: _ClassVar[ResponseOfferSnapshot.Result]
        REJECT_FORMAT: _ClassVar[ResponseOfferSnapshot.Result]
        REJECT_SENDER: _ClassVar[ResponseOfferSnapshot.Result]
    UNKNOWN: ResponseOfferSnapshot.Result
    ACCEPT: ResponseOfferSnapshot.Result
    ABORT: ResponseOfferSnapshot.Result
    REJECT: ResponseOfferSnapshot.Result
    REJECT_FORMAT: ResponseOfferSnapshot.Result
    REJECT_SENDER: ResponseOfferSnapshot.Result
    RESULT_FIELD_NUMBER: _ClassVar[int]
    result: ResponseOfferSnapshot.Result
    def __init__(self, result: _Optional[_Union[ResponseOfferSnapshot.Result, str]] = ...) -> None: ...

class ResponseLoadSnapshotChunk(_message.Message):
    __slots__ = ("chunk",)
    CHUNK_FIELD_NUMBER: _ClassVar[int]
    chunk: bytes
    def __init__(self, chunk: _Optional[bytes] = ...) -> None: ...

class ResponseApplySnapshotChunk(_message.Message):
    __slots__ = ("result", "refetch_chunks", "reject_senders")
    class Result(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        UNKNOWN: _ClassVar[ResponseApplySnapshotChunk.Result]
        ACCEPT: _ClassVar[ResponseApplySnapshotChunk.Result]
        ABORT: _ClassVar[ResponseApplySnapshotChunk.Result]
        RETRY: _ClassVar[ResponseApplySnapshotChunk.Result]
        RETRY_SNAPSHOT: _ClassVar[ResponseApplySnapshotChunk.Result]
        REJECT_SNAPSHOT: _ClassVar[ResponseApplySnapshotChunk.Result]
    UNKNOWN: ResponseApplySnapshotChunk.Result
    ACCEPT: ResponseApplySnapshotChunk.Result
    ABORT: ResponseApplySnapshotChunk.Result
    RETRY: ResponseApplySnapshotChunk.Result
    RETRY_SNAPSHOT: ResponseApplySnapshotChunk.Result
    REJECT_SNAPSHOT: ResponseApplySnapshotChunk.Result
    RESULT_FIELD_NUMBER: _ClassVar[int]
    REFETCH_CHUNKS_FIELD_NUMBER: _ClassVar[int]
    REJECT_SENDERS_FIELD_NUMBER: _ClassVar[int]
    result: ResponseApplySnapshotChunk.Result
    refetch_chunks: _containers.RepeatedScalarFieldContainer[int]
    reject_senders: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, result: _Optional[_Union[ResponseApplySnapshotChunk.Result, str]] = ..., refetch_chunks: _Optional[_Iterable[int]] = ..., reject_senders: _Optional[_Iterable[str]] = ...) -> None: ...

class ConsensusParams(_message.Message):
    __slots__ = ("block", "evidence", "validator", "version")
    BLOCK_FIELD_NUMBER: _ClassVar[int]
    EVIDENCE_FIELD_NUMBER: _ClassVar[int]
    VALIDATOR_FIELD_NUMBER: _ClassVar[int]
    VERSION_FIELD_NUMBER: _ClassVar[int]
    block: BlockParams
    evidence: _params_pb2.EvidenceParams
    validator: _params_pb2.ValidatorParams
    version: _params_pb2.VersionParams
    def __init__(self, block: _Optional[_Union[BlockParams, _Mapping]] = ..., evidence: _Optional[_Union[_params_pb2.EvidenceParams, _Mapping]] = ..., validator: _Optional[_Union[_params_pb2.ValidatorParams, _Mapping]] = ..., version: _Optional[_Union[_params_pb2.VersionParams, _Mapping]] = ...) -> None: ...

class BlockParams(_message.Message):
    __slots__ = ("max_bytes", "max_gas")
    MAX_BYTES_FIELD_NUMBER: _ClassVar[int]
    MAX_GAS_FIELD_NUMBER: _ClassVar[int]
    max_bytes: int
    max_gas: int
    def __init__(self, max_bytes: _Optional[int] = ..., max_gas: _Optional[int] = ...) -> None: ...

class LastCommitInfo(_message.Message):
    __slots__ = ("round", "votes")
    ROUND_FIELD_NUMBER: _ClassVar[int]
    VOTES_FIELD_NUMBER: _ClassVar[int]
    round: int
    votes: _containers.RepeatedCompositeFieldContainer[VoteInfo]
    def __init__(self, round: _Optional[int] = ..., votes: _Optional[_Iterable[_Union[VoteInfo, _Mapping]]] = ...) -> None: ...

class Event(_message.Message):
    __slots__ = ("type", "attributes")
    TYPE_FIELD_NUMBER: _ClassVar[int]
    ATTRIBUTES_FIELD_NUMBER: _ClassVar[int]
    type: str
    attributes: _containers.RepeatedCompositeFieldContainer[EventAttribute]
    def __init__(self, type: _Optional[str] = ..., attributes: _Optional[_Iterable[_Union[EventAttribute, _Mapping]]] = ...) -> None: ...

class EventAttribute(_message.Message):
    __slots__ = ("key", "value", "index")
    KEY_FIELD_NUMBER: _ClassVar[int]
    VALUE_FIELD_NUMBER: _ClassVar[int]
    INDEX_FIELD_NUMBER: _ClassVar[int]
    key: bytes
    value: bytes
    index: bool
    def __init__(self, key: _Optional[bytes] = ..., value: _Optional[bytes] = ..., index: bool = ...) -> None: ...

class TxResult(_message.Message):
    __slots__ = ("height", "index", "tx", "result")
    HEIGHT_FIELD_NUMBER: _ClassVar[int]
    INDEX_FIELD_NUMBER: _ClassVar[int]
    TX_FIELD_NUMBER: _ClassVar[int]
    RESULT_FIELD_NUMBER: _ClassVar[int]
    height: int
    index: int
    tx: bytes
    result: ResponseDeliverTx
    def __init__(self, height: _Optional[int] = ..., index: _Optional[int] = ..., tx: _Optional[bytes] = ..., result: _Optional[_Union[ResponseDeliverTx, _Mapping]] = ...) -> None: ...

class Validator(_message.Message):
    __slots__ = ("address", "power")
    ADDRESS_FIELD_NUMBER: _ClassVar[int]
    POWER_FIELD_NUMBER: _ClassVar[int]
    address: bytes
    power: int
    def __init__(self, address: _Optional[bytes] = ..., power: _Optional[int] = ...) -> None: ...

class ValidatorUpdate(_message.Message):
    __slots__ = ("pub_key", "power")
    PUB_KEY_FIELD_NUMBER: _ClassVar[int]
    POWER_FIELD_NUMBER: _ClassVar[int]
    pub_key: _keys_pb2.PublicKey
    power: int
    def __init__(self, pub_key: _Optional[_Union[_keys_pb2.PublicKey, _Mapping]] = ..., power: _Optional[int] = ...) -> None: ...

class VoteInfo(_message.Message):
    __slots__ = ("validator", "signed_last_block")
    VALIDATOR_FIELD_NUMBER: _ClassVar[int]
    SIGNED_LAST_BLOCK_FIELD_NUMBER: _ClassVar[int]
    validator: Validator
    signed_last_block: bool
    def __init__(self, validator: _Optional[_Union[Validator, _Mapping]] = ..., signed_last_block: bool = ...) -> None: ...

class Evidence(_message.Message):
    __slots__ = ("type", "validator", "height", "time", "total_voting_power")
    TYPE_FIELD_NUMBER: _ClassVar[int]
    VALIDATOR_FIELD_NUMBER: _ClassVar[int]
    HEIGHT_FIELD_NUMBER: _ClassVar[int]
    TIME_FIELD_NUMBER: _ClassVar[int]
    TOTAL_VOTING_POWER_FIELD_NUMBER: _ClassVar[int]
    type: EvidenceType
    validator: Validator
    height: int
    time: _timestamp_pb2.Timestamp
    total_voting_power: int
    def __init__(self, type: _Optional[_Union[EvidenceType, str]] = ..., validator: _Optional[_Union[Validator, _Mapping]] = ..., height: _Optional[int] = ..., time: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., total_voting_power: _Optional[int] = ...) -> None: ...

class Snapshot(_message.Message):
    __slots__ = ("height", "format", "chunks", "hash", "metadata")
    HEIGHT_FIELD_NUMBER: _ClassVar[int]
    FORMAT_FIELD_NUMBER: _ClassVar[int]
    CHUNKS_FIELD_NUMBER: _ClassVar[int]
    HASH_FIELD_NUMBER: _ClassVar[int]
    METADATA_FIELD_NUMBER: _ClassVar[int]
    height: int
    format: int
    chunks: int
    hash: bytes
    metadata: bytes
    def __init__(self, height: _Optional[int] = ..., format: _Optional[int] = ..., chunks: _Optional[int] = ..., hash: _Optional[bytes] = ..., metadata: _Optional[bytes] = ...) -> None: ...



from google.api import annotations_pb2 as _annotations_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class AppDescriptor(_message.Message):
    __slots__ = ("authn", "chain", "codec", "configuration", "query_services", "tx")
    AUTHN_FIELD_NUMBER: _ClassVar[int]
    CHAIN_FIELD_NUMBER: _ClassVar[int]
    CODEC_FIELD_NUMBER: _ClassVar[int]
    CONFIGURATION_FIELD_NUMBER: _ClassVar[int]
    QUERY_SERVICES_FIELD_NUMBER: _ClassVar[int]
    TX_FIELD_NUMBER: _ClassVar[int]
    authn: AuthnDescriptor
    chain: ChainDescriptor
    codec: CodecDescriptor
    configuration: ConfigurationDescriptor
    query_services: QueryServicesDescriptor
    tx: TxDescriptor
    def __init__(self, authn: _Optional[_Union[AuthnDescriptor, _Mapping]] = ..., chain: _Optional[_Union[ChainDescriptor, _Mapping]] = ..., codec: _Optional[_Union[CodecDescriptor, _Mapping]] = ..., configuration: _Optional[_Union[ConfigurationDescriptor, _Mapping]] = ..., query_services: _Optional[_Union[QueryServicesDescriptor, _Mapping]] = ..., tx: _Optional[_Union[TxDescriptor, _Mapping]] = ...) -> None: ...

class TxDescriptor(_message.Message):
    __slots__ = ("fullname", "msgs")
    FULLNAME_FIELD_NUMBER: _ClassVar[int]
    MSGS_FIELD_NUMBER: _ClassVar[int]
    fullname: str
    msgs: _containers.RepeatedCompositeFieldContainer[MsgDescriptor]
    def __init__(self, fullname: _Optional[str] = ..., msgs: _Optional[_Iterable[_Union[MsgDescriptor, _Mapping]]] = ...) -> None: ...

class AuthnDescriptor(_message.Message):
    __slots__ = ("sign_modes",)
    SIGN_MODES_FIELD_NUMBER: _ClassVar[int]
    sign_modes: _containers.RepeatedCompositeFieldContainer[SigningModeDescriptor]
    def __init__(self, sign_modes: _Optional[_Iterable[_Union[SigningModeDescriptor, _Mapping]]] = ...) -> None: ...

class SigningModeDescriptor(_message.Message):
    __slots__ = ("name", "number", "authn_info_provider_method_fullname")
    NAME_FIELD_NUMBER: _ClassVar[int]
    NUMBER_FIELD_NUMBER: _ClassVar[int]
    AUTHN_INFO_PROVIDER_METHOD_FULLNAME_FIELD_NUMBER: _ClassVar[int]
    name: str
    number: int
    authn_info_provider_method_fullname: str
    def __init__(self, name: _Optional[str] = ..., number: _Optional[int] = ..., authn_info_provider_method_fullname: _Optional[str] = ...) -> None: ...

class ChainDescriptor(_message.Message):
    __slots__ = ("id",)
    ID_FIELD_NUMBER: _ClassVar[int]
    id: str
    def __init__(self, id: _Optional[str] = ...) -> None: ...

class CodecDescriptor(_message.Message):
    __slots__ = ("interfaces",)
    INTERFACES_FIELD_NUMBER: _ClassVar[int]
    interfaces: _containers.RepeatedCompositeFieldContainer[InterfaceDescriptor]
    def __init__(self, interfaces: _Optional[_Iterable[_Union[InterfaceDescriptor, _Mapping]]] = ...) -> None: ...

class InterfaceDescriptor(_message.Message):
    __slots__ = ("fullname", "interface_accepting_messages", "interface_implementers")
    FULLNAME_FIELD_NUMBER: _ClassVar[int]
    INTERFACE_ACCEPTING_MESSAGES_FIELD_NUMBER: _ClassVar[int]
    INTERFACE_IMPLEMENTERS_FIELD_NUMBER: _ClassVar[int]
    fullname: str
    interface_accepting_messages: _containers.RepeatedCompositeFieldContainer[InterfaceAcceptingMessageDescriptor]
    interface_implementers: _containers.RepeatedCompositeFieldContainer[InterfaceImplementerDescriptor]
    def __init__(self, fullname: _Optional[str] = ..., interface_accepting_messages: _Optional[_Iterable[_Union[InterfaceAcceptingMessageDescriptor, _Mapping]]] = ..., interface_implementers: _Optional[_Iterable[_Union[InterfaceImplementerDescriptor, _Mapping]]] = ...) -> None: ...

class InterfaceImplementerDescriptor(_message.Message):
    __slots__ = ("fullname", "type_url")
    FULLNAME_FIELD_NUMBER: _ClassVar[int]
    TYPE_URL_FIELD_NUMBER: _ClassVar[int]
    fullname: str
    type_url: str
    def __init__(self, fullname: _Optional[str] = ..., type_url: _Optional[str] = ...) -> None: ...

class InterfaceAcceptingMessageDescriptor(_message.Message):
    __slots__ = ("fullname", "field_descriptor_names")
    FULLNAME_FIELD_NUMBER: _ClassVar[int]
    FIELD_DESCRIPTOR_NAMES_FIELD_NUMBER: _ClassVar[int]
    fullname: str
    field_descriptor_names: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, fullname: _Optional[str] = ..., field_descriptor_names: _Optional[_Iterable[str]] = ...) -> None: ...

class ConfigurationDescriptor(_message.Message):
    __slots__ = ("bech32_account_address_prefix",)
    BECH32_ACCOUNT_ADDRESS_PREFIX_FIELD_NUMBER: _ClassVar[int]
    bech32_account_address_prefix: str
    def __init__(self, bech32_account_address_prefix: _Optional[str] = ...) -> None: ...

class MsgDescriptor(_message.Message):
    __slots__ = ("msg_type_url",)
    MSG_TYPE_URL_FIELD_NUMBER: _ClassVar[int]
    msg_type_url: str
    def __init__(self, msg_type_url: _Optional[str] = ...) -> None: ...

class GetAuthnDescriptorRequest(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class GetAuthnDescriptorResponse(_message.Message):
    __slots__ = ("authn",)
    AUTHN_FIELD_NUMBER: _ClassVar[int]
    authn: AuthnDescriptor
    def __init__(self, authn: _Optional[_Union[AuthnDescriptor, _Mapping]] = ...) -> None: ...

class GetChainDescriptorRequest(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class GetChainDescriptorResponse(_message.Message):
    __slots__ = ("chain",)
    CHAIN_FIELD_NUMBER: _ClassVar[int]
    chain: ChainDescriptor
    def __init__(self, chain: _Optional[_Union[ChainDescriptor, _Mapping]] = ...) -> None: ...

class GetCodecDescriptorRequest(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class GetCodecDescriptorResponse(_message.Message):
    __slots__ = ("codec",)
    CODEC_FIELD_NUMBER: _ClassVar[int]
    codec: CodecDescriptor
    def __init__(self, codec: _Optional[_Union[CodecDescriptor, _Mapping]] = ...) -> None: ...

class GetConfigurationDescriptorRequest(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class GetConfigurationDescriptorResponse(_message.Message):
    __slots__ = ("config",)
    CONFIG_FIELD_NUMBER: _ClassVar[int]
    config: ConfigurationDescriptor
    def __init__(self, config: _Optional[_Union[ConfigurationDescriptor, _Mapping]] = ...) -> None: ...

class GetQueryServicesDescriptorRequest(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class GetQueryServicesDescriptorResponse(_message.Message):
    __slots__ = ("queries",)
    QUERIES_FIELD_NUMBER: _ClassVar[int]
    queries: QueryServicesDescriptor
    def __init__(self, queries: _Optional[_Union[QueryServicesDescriptor, _Mapping]] = ...) -> None: ...

class GetTxDescriptorRequest(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class GetTxDescriptorResponse(_message.Message):
    __slots__ = ("tx",)
    TX_FIELD_NUMBER: _ClassVar[int]
    tx: TxDescriptor
    def __init__(self, tx: _Optional[_Union[TxDescriptor, _Mapping]] = ...) -> None: ...

class QueryServicesDescriptor(_message.Message):
    __slots__ = ("query_services",)
    QUERY_SERVICES_FIELD_NUMBER: _ClassVar[int]
    query_services: _containers.RepeatedCompositeFieldContainer[QueryServiceDescriptor]
    def __init__(self, query_services: _Optional[_Iterable[_Union[QueryServiceDescriptor, _Mapping]]] = ...) -> None: ...

class QueryServiceDescriptor(_message.Message):
    __slots__ = ("fullname", "is_module", "methods")
    FULLNAME_FIELD_NUMBER: _ClassVar[int]
    IS_MODULE_FIELD_NUMBER: _ClassVar[int]
    METHODS_FIELD_NUMBER: _ClassVar[int]
    fullname: str
    is_module: bool
    methods: _containers.RepeatedCompositeFieldContainer[QueryMethodDescriptor]
    def __init__(self, fullname: _Optional[str] = ..., is_module: bool = ..., methods: _Optional[_Iterable[_Union[QueryMethodDescriptor, _Mapping]]] = ...) -> None: ...

class QueryMethodDescriptor(_message.Message):
    __slots__ = ("name", "full_query_path")
    NAME_FIELD_NUMBER: _ClassVar[int]
    FULL_QUERY_PATH_FIELD_NUMBER: _ClassVar[int]
    name: str
    full_query_path: str
    def __init__(self, name: _Optional[str] = ..., full_query_path: _Optional[str] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: cosmos_proto/cosmos.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'cosmos_proto/cosmos.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import descriptor_pb2 as google_dot_protobuf_dot_descriptor__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x19\x63osmos_proto/cosmos.proto\x12\x0c\x63osmos_proto\x1a google/protobuf/descriptor.proto\"8\n\x13InterfaceDescriptor\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\"c\n\x10ScalarDescriptor\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12,\n\nfield_type\x18\x03 \x03(\x0e\x32\x18.cosmos_proto.ScalarType*X\n\nScalarType\x12\x1b\n\x17SCALAR_TYPE_UNSPECIFIED\x10\x00\x12\x16\n\x12SCALAR_TYPE_STRING\x10\x01\x12\x15\n\x11SCALAR_TYPE_BYTES\x10\x02:9\n\x0fmethod_added_in\x12\x1e.google.protobuf.MethodOptions\x18\xc9\xd6\x05 \x01(\t:?\n\x14implements_interface\x12\x1f.google.protobuf.MessageOptions\x18\xc9\xd6\x05 \x03(\t:;\n\x10message_added_in\x12\x1f.google.protobuf.MessageOptions\x18\xca\xd6\x05 \x01(\t::\n\x11\x61\x63\x63\x65pts_interface\x12\x1d.google.protobuf.FieldOptions\x18\xc9\xd6\x05 \x01(\t:/\n\x06scalar\x12\x1d.google.protobuf.FieldOptions\x18\xca\xd6\x05 \x01(\t:7\n\x0e\x66ield_added_in\x12\x1d.google.protobuf.FieldOptions\x18\xcb\xd6\x05 \x01(\t:\\\n\x11\x64\x65\x63lare_interface\x12\x1c.google.protobuf.FileOptions\x18\xbd\xb3\x30 \x03(\x0b\x32!.cosmos_proto.InterfaceDescriptor:V\n\x0e\x64\x65\x63lare_scalar\x12\x1c.google.protobuf.FileOptions\x18\xbe\xb3\x30 \x03(\x0b\x32\x1e.cosmos_proto.ScalarDescriptor:5\n\rfile_added_in\x12\x1c.google.protobuf.FileOptions\x18\xbf\xb3\x30 \x01(\tB-Z+github.com/cosmos/cosmos-proto;cosmos_protob\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos_proto.cosmos_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z+github.com/cosmos/cosmos-proto;cosmos_proto'
  _globals['_SCALARTYPE']._serialized_start=236
  _globals['_SCALARTYPE']._serialized_end=324
  _globals['_INTERFACEDESCRIPTOR']._serialized_start=77
  _globals['_INTERFACEDESCRIPTOR']._serialized_end=133
  _globals['_SCALARDESCRIPTOR']._serialized_start=135
  _globals['_SCALARDESCRIPTOR']._serialized_end=234
# @@protoc_insertion_point(module_scope)



from gogoproto import gogo_pb2 as _gogo_pb2
from ibc.core.client.v1 import client_pb2 as _client_pb2
from ibc.core.channel.v1 import channel_pb2 as _channel_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class MsgChannelOpenInit(_message.Message):
    __slots__ = ("port_id", "channel", "signer")
    PORT_ID_FIELD_NUMBER: _ClassVar[int]
    CHANNEL_FIELD_NUMBER: _ClassVar[int]
    SIGNER_FIELD_NUMBER: _ClassVar[int]
    port_id: str
    channel: _channel_pb2.Channel
    signer: str
    def __init__(self, port_id: _Optional[str] = ..., channel: _Optional[_Union[_channel_pb2.Channel, _Mapping]] = ..., signer: _Optional[str] = ...) -> None: ...

class MsgChannelOpenInitResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class MsgChannelOpenTry(_message.Message):
    __slots__ = ("port_id", "previous_channel_id", "channel", "counterparty_version", "proof_init", "proof_height", "signer")
    PORT_ID_FIELD_NUMBER: _ClassVar[int]
    PREVIOUS_CHANNEL_ID_FIELD_NUMBER: _ClassVar[int]
    CHANNEL_FIELD_NUMBER: _ClassVar[int]
    COUNTERPARTY_VERSION_FIELD_NUMBER: _ClassVar[int]
    PROOF_INIT_FIELD_NUMBER: _ClassVar[int]
    PROOF_HEIGHT_FIELD_NUMBER: _ClassVar[int]
    SIGNER_FIELD_NUMBER: _ClassVar[int]
    port_id: str
    previous_channel_id: str
    channel: _channel_pb2.Channel
    counterparty_version: str
    proof_init: bytes
    proof_height: _client_pb2.Height
    signer: str
    def __init__(self, port_id: _Optional[str] = ..., previous_channel_id: _Optional[str] = ..., channel: _Optional[_Union[_channel_pb2.Channel, _Mapping]] = ..., counterparty_version: _Optional[str] = ..., proof_init: _Optional[bytes] = ..., proof_height: _Optional[_Union[_client_pb2.Height, _Mapping]] = ..., signer: _Optional[str] = ...) -> None: ...

class MsgChannelOpenTryResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class MsgChannelOpenAck(_message.Message):
    __slots__ = ("port_id", "channel_id", "counterparty_channel_id", "counterparty_version", "proof_try", "proof_height", "signer")
    PORT_ID_FIELD_NUMBER: _ClassVar[int]
    CHANNEL_ID_FIELD_NUMBER: _ClassVar[int]
    COUNTERPARTY_CHANNEL_ID_FIELD_NUMBER: _ClassVar[int]
    COUNTERPARTY_VERSION_FIELD_NUMBER: _ClassVar[int]
    PROOF_TRY_FIELD_NUMBER: _ClassVar[int]
    PROOF_HEIGHT_FIELD_NUMBER: _ClassVar[int]
    SIGNER_FIELD_NUMBER: _ClassVar[int]
    port_id: str
    channel_id: str
    counterparty_channel_id: str
    counterparty_version: str
    proof_try: bytes
    proof_height: _client_pb2.Height
    signer: str
    def __init__(self, port_id: _Optional[str] = ..., channel_id: _Optional[str] = ..., counterparty_channel_id: _Optional[str] = ..., counterparty_version: _Optional[str] = ..., proof_try: _Optional[bytes] = ..., proof_height: _Optional[_Union[_client_pb2.Height, _Mapping]] = ..., signer: _Optional[str] = ...) -> None: ...

class MsgChannelOpenAckResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class MsgChannelOpenConfirm(_message.Message):
    __slots__ = ("port_id", "channel_id", "proof_ack", "proof_height", "signer")
    PORT_ID_FIELD_NUMBER: _ClassVar[int]
    CHANNEL_ID_FIELD_NUMBER: _ClassVar[int]
    PROOF_ACK_FIELD_NUMBER: _ClassVar[int]
    PROOF_HEIGHT_FIELD_NUMBER: _ClassVar[int]
    SIGNER_FIELD_NUMBER: _ClassVar[int]
    port_id: str
    channel_id: str
    proof_ack: bytes
    proof_height: _client_pb2.Height
    signer: str
    def __init__(self, port_id: _Optional[str] = ..., channel_id: _Optional[str] = ..., proof_ack: _Optional[bytes] = ..., proof_height: _Optional[_Union[_client_pb2.Height, _Mapping]] = ..., signer: _Optional[str] = ...) -> None: ...

class MsgChannelOpenConfirmResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class MsgChannelCloseInit(_message.Message):
    __slots__ = ("port_id", "channel_id", "signer")
    PORT_ID_FIELD_NUMBER: _ClassVar[int]
    CHANNEL_ID_FIELD_NUMBER: _ClassVar[int]
    SIGNER_FIELD_NUMBER: _ClassVar[int]
    port_id: str
    channel_id: str
    signer: str
    def __init__(self, port_id: _Optional[str] = ..., channel_id: _Optional[str] = ..., signer: _Optional[str] = ...) -> None: ...

class MsgChannelCloseInitResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class MsgChannelCloseConfirm(_message.Message):
    __slots__ = ("port_id", "channel_id", "proof_init", "proof_height", "signer")
    PORT_ID_FIELD_NUMBER: _ClassVar[int]
    CHANNEL_ID_FIELD_NUMBER: _ClassVar[int]
    PROOF_INIT_FIELD_NUMBER: _ClassVar[int]
    PROOF_HEIGHT_FIELD_NUMBER: _ClassVar[int]
    SIGNER_FIELD_NUMBER: _ClassVar[int]
    port_id: str
    channel_id: str
    proof_init: bytes
    proof_height: _client_pb2.Height
    signer: str
    def __init__(self, port_id: _Optional[str] = ..., channel_id: _Optional[str] = ..., proof_init: _Optional[bytes] = ..., proof_height: _Optional[_Union[_client_pb2.Height, _Mapping]] = ..., signer: _Optional[str] = ...) -> None: ...

class MsgChannelCloseConfirmResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class MsgRecvPacket(_message.Message):
    __slots__ = ("packet", "proof_commitment", "proof_height", "signer")
    PACKET_FIELD_NUMBER: _ClassVar[int]
    PROOF_COMMITMENT_FIELD_NUMBER: _ClassVar[int]
    PROOF_HEIGHT_FIELD_NUMBER: _ClassVar[int]
    SIGNER_FIELD_NUMBER: _ClassVar[int]
    packet: _channel_pb2.Packet
    proof_commitment: bytes
    proof_height: _client_pb2.Height
    signer: str
    def __init__(self, packet: _Optional[_Union[_channel_pb2.Packet, _Mapping]] = ..., proof_commitment: _Optional[bytes] = ..., proof_height: _Optional[_Union[_client_pb2.Height, _Mapping]] = ..., signer: _Optional[str] = ...) -> None: ...

class MsgRecvPacketResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class MsgTimeout(_message.Message):
    __slots__ = ("packet", "proof_unreceived", "proof_height", "next_sequence_recv", "signer")
    PACKET_FIELD_NUMBER: _ClassVar[int]
    PROOF_UNRECEIVED_FIELD_NUMBER: _ClassVar[int]
    PROOF_HEIGHT_FIELD_NUMBER: _ClassVar[int]
    NEXT_SEQUENCE_RECV_FIELD_NUMBER: _ClassVar[int]
    SIGNER_FIELD_NUMBER: _ClassVar[int]
    packet: _channel_pb2.Packet
    proof_unreceived: bytes
    proof_height: _client_pb2.Height
    next_sequence_recv: int
    signer: str
    def __init__(self, packet: _Optional[_Union[_channel_pb2.Packet, _Mapping]] = ..., proof_unreceived: _Optional[bytes] = ..., proof_height: _Optional[_Union[_client_pb2.Height, _Mapping]] = ..., next_sequence_recv: _Optional[int] = ..., signer: _Optional[str] = ...) -> None: ...

class MsgTimeoutResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class MsgTimeoutOnClose(_message.Message):
    __slots__ = ("packet", "proof_unreceived", "proof_close", "proof_height", "next_sequence_recv", "signer")
    PACKET_FIELD_NUMBER: _ClassVar[int]
    PROOF_UNRECEIVED_FIELD_NUMBER: _ClassVar[int]
    PROOF_CLOSE_FIELD_NUMBER: _ClassVar[int]
    PROOF_HEIGHT_FIELD_NUMBER: _ClassVar[int]
    NEXT_SEQUENCE_RECV_FIELD_NUMBER: _ClassVar[int]
    SIGNER_FIELD_NUMBER: _ClassVar[int]
    packet: _channel_pb2.Packet
    proof_unreceived: bytes
    proof_close: bytes
    proof_height: _client_pb2.Height
    next_sequence_recv: int
    signer: str
    def __init__(self, packet: _Optional[_Union[_channel_pb2.Packet, _Mapping]] = ..., proof_unreceived: _Optional[bytes] = ..., proof_close: _Optional[bytes] = ..., proof_height: _Optional[_Union[_client_pb2.Height, _Mapping]] = ..., next_sequence_recv: _Optional[int] = ..., signer: _Optional[str] = ...) -> None: ...

class MsgTimeoutOnCloseResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class MsgAcknowledgement(_message.Message):
    __slots__ = ("packet", "acknowledgement", "proof_acked", "proof_height", "signer")
    PACKET_FIELD_NUMBER: _ClassVar[int]
    ACKNOWLEDGEMENT_FIELD_NUMBER: _ClassVar[int]
    PROOF_ACKED_FIELD_NUMBER: _ClassVar[int]
    PROOF_HEIGHT_FIELD_NUMBER: _ClassVar[int]
    SIGNER_FIELD_NUMBER: _ClassVar[int]
    packet: _channel_pb2.Packet
    acknowledgement: bytes
    proof_acked: bytes
    proof_height: _client_pb2.Height
    signer: str
    def __init__(self, packet: _Optional[_Union[_channel_pb2.Packet, _Mapping]] = ..., acknowledgement: _Optional[bytes] = ..., proof_acked: _Optional[bytes] = ..., proof_height: _Optional[_Union[_client_pb2.Height, _Mapping]] = ..., signer: _Optional[str] = ...) -> None: ...

class MsgAcknowledgementResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...



from cosmos.base.v1beta1 import coin_pb2 as _coin_pb2
from cosmos.gov.v1beta1 import gov_pb2 as _gov_pb2
from cosmos_proto import cosmos_pb2 as _cosmos_pb2
from gogoproto import gogo_pb2 as _gogo_pb2
from google.protobuf import any_pb2 as _any_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class MsgSubmitProposal(_message.Message):
    __slots__ = ("content", "initial_deposit", "proposer")
    CONTENT_FIELD_NUMBER: _ClassVar[int]
    INITIAL_DEPOSIT_FIELD_NUMBER: _ClassVar[int]
    PROPOSER_FIELD_NUMBER: _ClassVar[int]
    content: _any_pb2.Any
    initial_deposit: _containers.RepeatedCompositeFieldContainer[_coin_pb2.Coin]
    proposer: str
    def __init__(self, content: _Optional[_Union[_any_pb2.Any, _Mapping]] = ..., initial_deposit: _Optional[_Iterable[_Union[_coin_pb2.Coin, _Mapping]]] = ..., proposer: _Optional[str] = ...) -> None: ...

class MsgSubmitProposalResponse(_message.Message):
    __slots__ = ("proposal_id",)
    PROPOSAL_ID_FIELD_NUMBER: _ClassVar[int]
    proposal_id: int
    def __init__(self, proposal_id: _Optional[int] = ...) -> None: ...

class MsgVote(_message.Message):
    __slots__ = ("proposal_id", "voter", "option")
    PROPOSAL_ID_FIELD_NUMBER: _ClassVar[int]
    VOTER_FIELD_NUMBER: _ClassVar[int]
    OPTION_FIELD_NUMBER: _ClassVar[int]
    proposal_id: int
    voter: str
    option: _gov_pb2.VoteOption
    def __init__(self, proposal_id: _Optional[int] = ..., voter: _Optional[str] = ..., option: _Optional[_Union[_gov_pb2.VoteOption, str]] = ...) -> None: ...

class MsgVoteResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class MsgVoteWeighted(_message.Message):
    __slots__ = ("proposal_id", "voter", "options")
    PROPOSAL_ID_FIELD_NUMBER: _ClassVar[int]
    VOTER_FIELD_NUMBER: _ClassVar[int]
    OPTIONS_FIELD_NUMBER: _ClassVar[int]
    proposal_id: int
    voter: str
    options: _containers.RepeatedCompositeFieldContainer[_gov_pb2.WeightedVoteOption]
    def __init__(self, proposal_id: _Optional[int] = ..., voter: _Optional[str] = ..., options: _Optional[_Iterable[_Union[_gov_pb2.WeightedVoteOption, _Mapping]]] = ...) -> None: ...

class MsgVoteWeightedResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class MsgDeposit(_message.Message):
    __slots__ = ("proposal_id", "depositor", "amount")
    PROPOSAL_ID_FIELD_NUMBER: _ClassVar[int]
    DEPOSITOR_FIELD_NUMBER: _ClassVar[int]
    AMOUNT_FIELD_NUMBER: _ClassVar[int]
    proposal_id: int
    depositor: str
    amount: _containers.RepeatedCompositeFieldContainer[_coin_pb2.Coin]
    def __init__(self, proposal_id: _Optional[int] = ..., depositor: _Optional[str] = ..., amount: _Optional[_Iterable[_Union[_coin_pb2.Coin, _Mapping]]] = ...) -> None: ...

class MsgDepositResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...



from cosmos.base.v1beta1 import coin_pb2 as _coin_pb2
from gogoproto import gogo_pb2 as _gogo_pb2
from cosmwasm.wasm.v1 import types_pb2 as _types_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class MsgStoreCode(_message.Message):
    __slots__ = ("sender", "wasm_byte_code", "instantiate_permission")
    SENDER_FIELD_NUMBER: _ClassVar[int]
    WASM_BYTE_CODE_FIELD_NUMBER: _ClassVar[int]
    INSTANTIATE_PERMISSION_FIELD_NUMBER: _ClassVar[int]
    sender: str
    wasm_byte_code: bytes
    instantiate_permission: _types_pb2.AccessConfig
    def __init__(self, sender: _Optional[str] = ..., wasm_byte_code: _Optional[bytes] = ..., instantiate_permission: _Optional[_Union[_types_pb2.AccessConfig, _Mapping]] = ...) -> None: ...

class MsgStoreCodeResponse(_message.Message):
    __slots__ = ("code_id",)
    CODE_ID_FIELD_NUMBER: _ClassVar[int]
    code_id: int
    def __init__(self, code_id: _Optional[int] = ...) -> None: ...

class MsgInstantiateContract(_message.Message):
    __slots__ = ("sender", "admin", "code_id", "label", "msg", "funds")
    SENDER_FIELD_NUMBER: _ClassVar[int]
    ADMIN_FIELD_NUMBER: _ClassVar[int]
    CODE_ID_FIELD_NUMBER: _ClassVar[int]
    LABEL_FIELD_NUMBER: _ClassVar[int]
    MSG_FIELD_NUMBER: _ClassVar[int]
    FUNDS_FIELD_NUMBER: _ClassVar[int]
    sender: str
    admin: str
    code_id: int
    label: str
    msg: bytes
    funds: _containers.RepeatedCompositeFieldContainer[_coin_pb2.Coin]
    def __init__(self, sender: _Optional[str] = ..., admin: _Optional[str] = ..., code_id: _Optional[int] = ..., label: _Optional[str] = ..., msg: _Optional[bytes] = ..., funds: _Optional[_Iterable[_Union[_coin_pb2.Coin, _Mapping]]] = ...) -> None: ...

class MsgInstantiateContractResponse(_message.Message):
    __slots__ = ("address", "data")
    ADDRESS_FIELD_NUMBER: _ClassVar[int]
    DATA_FIELD_NUMBER: _ClassVar[int]
    address: str
    data: bytes
    def __init__(self, address: _Optional[str] = ..., data: _Optional[bytes] = ...) -> None: ...

class MsgExecuteContract(_message.Message):
    __slots__ = ("sender", "contract", "msg", "funds")
    SENDER_FIELD_NUMBER: _ClassVar[int]
    CONTRACT_FIELD_NUMBER: _ClassVar[int]
    MSG_FIELD_NUMBER: _ClassVar[int]
    FUNDS_FIELD_NUMBER: _ClassVar[int]
    sender: str
    contract: str
    msg: bytes
    funds: _containers.RepeatedCompositeFieldContainer[_coin_pb2.Coin]
    def __init__(self, sender: _Optional[str] = ..., contract: _Optional[str] = ..., msg: _Optional[bytes] = ..., funds: _Optional[_Iterable[_Union[_coin_pb2.Coin, _Mapping]]] = ...) -> None: ...

class MsgExecuteContractResponse(_message.Message):
    __slots__ = ("data",)
    DATA_FIELD_NUMBER: _ClassVar[int]
    data: bytes
    def __init__(self, data: _Optional[bytes] = ...) -> None: ...

class MsgMigrateContract(_message.Message):
    __slots__ = ("sender", "contract", "code_id", "msg")
    SENDER_FIELD_NUMBER: _ClassVar[int]
    CONTRACT_FIELD_NUMBER: _ClassVar[int]
    CODE_ID_FIELD_NUMBER: _ClassVar[int]
    MSG_FIELD_NUMBER: _ClassVar[int]
    sender: str
    contract: str
    code_id: int
    msg: bytes
    def __init__(self, sender: _Optional[str] = ..., contract: _Optional[str] = ..., code_id: _Optional[int] = ..., msg: _Optional[bytes] = ...) -> None: ...

class MsgMigrateContractResponse(_message.Message):
    __slots__ = ("data",)
    DATA_FIELD_NUMBER: _ClassVar[int]
    data: bytes
    def __init__(self, data: _Optional[bytes] = ...) -> None: ...

class MsgUpdateAdmin(_message.Message):
    __slots__ = ("sender", "new_admin", "contract")
    SENDER_FIELD_NUMBER: _ClassVar[int]
    NEW_ADMIN_FIELD_NUMBER: _ClassVar[int]
    CONTRACT_FIELD_NUMBER: _ClassVar[int]
    sender: str
    new_admin: str
    contract: str
    def __init__(self, sender: _Optional[str] = ..., new_admin: _Optional[str] = ..., contract: _Optional[str] = ...) -> None: ...

class MsgUpdateAdminResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class MsgClearAdmin(_message.Message):
    __slots__ = ("sender", "contract")
    SENDER_FIELD_NUMBER: _ClassVar[int]
    CONTRACT_FIELD_NUMBER: _ClassVar[int]
    sender: str
    contract: str
    def __init__(self, sender: _Optional[str] = ..., contract: _Optional[str] = ...) -> None: ...

class MsgClearAdminResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...



import base64
import json
from typing import Any, Dict, List

from google.protobuf.json_format import Parse, ParseDict

from neurionpy.common.rest_client import RestClient
from neurionpy.common.utils import json_encode
from neurionpy.protos.cosmos.crypto.secp256k1.keys_pb2 import (  # noqa: F401  # pylint: disable=unused-import
    PubKey as ProtoPubKey,
)
from neurionpy.protos.cosmos.tx.v1beta1.service_pb2 import (
    BroadcastTxRequest,
    BroadcastTxResponse,
    GetTxRequest,
    GetTxResponse,
    GetTxsEventRequest,
    GetTxsEventResponse,
    SimulateRequest,
    SimulateResponse,
)
from neurionpy.protos.cosmwasm.wasm.v1.tx_pb2 import (  # noqa: F401  # pylint: disable=unused-import
    MsgExecuteContract,
    MsgInstantiateContract,
    MsgStoreCode,
)
from neurionpy.tx.interface import TxInterface


# Unused imports are required to make sure that related types get generated - Parse and ParseDict fail without them


class TxRestClient(TxInterface):
    """Tx REST client."""

    API_URL = "/cosmos/tx/v1beta1"

    def __init__(self, rest_client: RestClient) -> None:
        """
        Create a Tx rest client.

        :param rest_client: RestClient api
        """
        self.rest_client = rest_client

    def Simulate(self, request: SimulateRequest) -> SimulateResponse:
        """
        Simulate executing a transaction to estimate gas usage.

        :param request: SimulateRequest
        :return: SimulateResponse
        """
        response = self.rest_client.post(
            f"{self.API_URL}/simulate",
            request,
        )
        return Parse(response, SimulateResponse())

    def GetTx(self, request: GetTxRequest) -> GetTxResponse:
        """
        GetTx fetches a tx by hash.

        :param request: GetTxRequest
        :return: GetTxResponse
        """
        response = self.rest_client.get(f"{self.API_URL}/txs/{request.hash}")

        # JSON in case of CosmWasm messages workaround
        dict_response = json.loads(response)
        self._fix_messages(dict_response["tx"]["body"]["messages"])
        self._fix_messages(dict_response["tx_response"]["tx"]["body"]["messages"])

        return ParseDict(dict_response, GetTxResponse())

    def BroadcastTx(self, request: BroadcastTxRequest) -> BroadcastTxResponse:
        """
        BroadcastTx broadcast transaction.

        :param request: BroadcastTxRequest
        :return: BroadcastTxResponse
        """
        response = self.rest_client.post(f"{self.API_URL}/txs", request)
        return Parse(response, BroadcastTxResponse())

    def GetTxsEvent(self, request: GetTxsEventRequest) -> GetTxsEventResponse:
        """
        GetTxsEvent fetches txs by event.

        :param request: GetTxsEventRequest
        :return: GetTxsEventResponse
        """
        response = self.rest_client.get(f"{self.API_URL}/txs", request)

        # JSON in case of CosmWasm messages workaround
        dict_response = json.loads(response)
        for tx in dict_response["txs"]:
            self._fix_messages(tx["body"]["messages"])

        for tx_response in dict_response["tx_responses"]:
            self._fix_messages(tx_response["tx"]["body"]["messages"])

        return ParseDict(dict_response, GetTxsEventResponse())

    @staticmethod
    def _fix_messages(messages: List[Dict[str, Any]]):
        """
        Fix for REST api response in case of CosmWasm messages contains dict instead of base64 encoded string.

        :param messages: List of message in Tx response
        """
        for message in messages:
            if message["@type"] == "/cosmwasm.wasm.v1.MsgInstantiateContract":
                message["msg"] = base64.b64encode(
                    json_encode(message["msg"]).encode("UTF8")
                ).decode()
            if message["@type"] == "/cosmwasm.wasm.v1.MsgExecuteContract":
                message["msg"] = base64.b64encode(
                    json_encode(message["msg"]).encode("UTF8")
                ).decode()
            if message["@type"] == "/cosmwasm.wasm.v1.MsgMigrateContract":
                message["msg"] = base64.b64encode(
                    json_encode(message["msg"]).encode("UTF8")
                ).decode()
